/********************************************************************************
** Form generated from reading UI file 'gm_addscriptdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GM_ADDSCRIPTDIALOG_H
#define UI_GM_ADDSCRIPTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_GM_AddScriptDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *iconLabel;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_3;
    QTextBrowser *textBrowser;
    QLabel *label_5;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *showSource;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *GM_AddScriptDialog)
    {
        if (GM_AddScriptDialog->objectName().isEmpty())
            GM_AddScriptDialog->setObjectName("GM_AddScriptDialog");
        GM_AddScriptDialog->resize(422, 379);
        verticalLayout = new QVBoxLayout(GM_AddScriptDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        iconLabel = new QLabel(GM_AddScriptDialog);
        iconLabel->setObjectName("iconLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(iconLabel);

        label_2 = new QLabel(GM_AddScriptDialog);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        label_3 = new QLabel(GM_AddScriptDialog);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_3);

        textBrowser = new QTextBrowser(GM_AddScriptDialog);
        textBrowser->setObjectName("textBrowser");

        verticalLayout->addWidget(textBrowser);

        label_5 = new QLabel(GM_AddScriptDialog);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_5);

        label_4 = new QLabel(GM_AddScriptDialog);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        showSource = new QPushButton(GM_AddScriptDialog);
        showSource->setObjectName("showSource");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(showSource->sizePolicy().hasHeightForWidth());
        showSource->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(showSource);

        buttonBox = new QDialogButtonBox(GM_AddScriptDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::No|QDialogButtonBox::Yes);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(GM_AddScriptDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, GM_AddScriptDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, GM_AddScriptDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(GM_AddScriptDialog);
    } // setupUi

    void retranslateUi(QDialog *GM_AddScriptDialog)
    {
        GM_AddScriptDialog->setWindowTitle(QCoreApplication::translate("GM_AddScriptDialog", "GreaseMonkey Installation", nullptr));
        label_2->setText(QCoreApplication::translate("GM_AddScriptDialog", "<h3>GreaseMonkey Installation</h3>", nullptr));
        label_3->setText(QCoreApplication::translate("GM_AddScriptDialog", "You are about to install this userscript into GreaseMonkey:", nullptr));
        label_5->setText(QCoreApplication::translate("GM_AddScriptDialog", "<b>You should only install scripts from sources you trust!</b>", nullptr));
        label_4->setText(QCoreApplication::translate("GM_AddScriptDialog", "Are you sure you want to install it?", nullptr));
        showSource->setText(QCoreApplication::translate("GM_AddScriptDialog", "Show source code of script", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GM_AddScriptDialog: public Ui_GM_AddScriptDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GM_ADDSCRIPTDIALOG_H
