/********************************************************************************
** Form generated from reading UI file 'downloadoptionsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOWNLOADOPTIONSDIALOG_H
#define UI_DOWNLOADOPTIONSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "clickablelabel.h"
#include "squeezelabelv2.h"

QT_BEGIN_NAMESPACE

class Ui_DownloadOptionsDialog
{
public:
    QGridLayout *gridLayout_2;
    QDialogButtonBox *buttonBox;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QRadioButton *radioOpen;
    QRadioButton *radioSave;
    QRadioButton *radioExternal;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_4;
    QLabel *iconLabel;
    SqueezeLabelV2 *fileName;
    QFrame *mimeFrame;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_5;
    QLabel *mimeName;
    QFrame *fromFrame;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_3;
    QLabel *fromServer;
    ClickableLabel *copyDownloadLink;
    QLabel *label;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QDialog *DownloadOptionsDialog)
    {
        if (DownloadOptionsDialog->objectName().isEmpty())
            DownloadOptionsDialog->setObjectName("DownloadOptionsDialog");
        DownloadOptionsDialog->setMinimumSize(QSize(400, 0));
        gridLayout_2 = new QGridLayout(DownloadOptionsDialog);
        gridLayout_2->setObjectName("gridLayout_2");
        buttonBox = new QDialogButtonBox(DownloadOptionsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_2->addWidget(buttonBox, 9, 0, 1, 3);

        groupBox = new QGroupBox(DownloadOptionsDialog);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 0, 1, 1);

        radioOpen = new QRadioButton(groupBox);
        radioOpen->setObjectName("radioOpen");

        gridLayout->addWidget(radioOpen, 0, 1, 1, 1);

        radioSave = new QRadioButton(groupBox);
        radioSave->setObjectName("radioSave");
        radioSave->setChecked(true);

        gridLayout->addWidget(radioSave, 1, 1, 1, 1);

        radioExternal = new QRadioButton(groupBox);
        radioExternal->setObjectName("radioExternal");

        gridLayout->addWidget(radioExternal, 2, 1, 1, 1);


        gridLayout_2->addWidget(groupBox, 7, 0, 1, 3);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(7);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_4 = new QSpacerItem(8, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);

        iconLabel = new QLabel(DownloadOptionsDialog);
        iconLabel->setObjectName("iconLabel");
        iconLabel->setMinimumSize(QSize(24, 24));
        iconLabel->setMaximumSize(QSize(24, 24));

        horizontalLayout_3->addWidget(iconLabel);

        fileName = new SqueezeLabelV2(DownloadOptionsDialog);
        fileName->setObjectName("fileName");
        fileName->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_3->addWidget(fileName);


        verticalLayout->addLayout(horizontalLayout_3);

        mimeFrame = new QFrame(DownloadOptionsDialog);
        mimeFrame->setObjectName("mimeFrame");
        horizontalLayout = new QHBoxLayout(mimeFrame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        label_5 = new QLabel(mimeFrame);
        label_5->setObjectName("label_5");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_5);

        mimeName = new QLabel(mimeFrame);
        mimeName->setObjectName("mimeName");

        horizontalLayout->addWidget(mimeName);


        verticalLayout->addWidget(mimeFrame);

        fromFrame = new QFrame(DownloadOptionsDialog);
        fromFrame->setObjectName("fromFrame");
        horizontalLayout_2 = new QHBoxLayout(fromFrame);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        label_3 = new QLabel(fromFrame);
        label_3->setObjectName("label_3");
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(label_3);

        fromServer = new QLabel(fromFrame);
        fromServer->setObjectName("fromServer");
        sizePolicy.setHeightForWidth(fromServer->sizePolicy().hasHeightForWidth());
        fromServer->setSizePolicy(sizePolicy);
        fromServer->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(fromServer);

        copyDownloadLink = new ClickableLabel(fromFrame);
        copyDownloadLink->setObjectName("copyDownloadLink");
        copyDownloadLink->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        copyDownloadLink->setProperty("html-link-look", QVariant(true));

        horizontalLayout_2->addWidget(copyDownloadLink);


        verticalLayout->addWidget(fromFrame);


        gridLayout_2->addLayout(verticalLayout, 3, 0, 1, 3);

        label = new QLabel(DownloadOptionsDialog);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 3);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 8, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 4, 1, 1, 1);


        retranslateUi(DownloadOptionsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, DownloadOptionsDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, DownloadOptionsDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(DownloadOptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *DownloadOptionsDialog)
    {
        groupBox->setTitle(QCoreApplication::translate("DownloadOptionsDialog", "What should Falkon do with this file?", nullptr));
        radioOpen->setText(QCoreApplication::translate("DownloadOptionsDialog", "Open...", nullptr));
        radioSave->setText(QCoreApplication::translate("DownloadOptionsDialog", "Save File", nullptr));
        radioExternal->setText(QCoreApplication::translate("DownloadOptionsDialog", "Download with External Manager", nullptr));
        fileName->setText(QString());
        label_5->setText(QCoreApplication::translate("DownloadOptionsDialog", "which is:", nullptr));
        label_3->setText(QCoreApplication::translate("DownloadOptionsDialog", "from:", nullptr));
        fromServer->setText(QString());
        copyDownloadLink->setText(QCoreApplication::translate("DownloadOptionsDialog", "Copy download link", nullptr));
        label->setText(QCoreApplication::translate("DownloadOptionsDialog", "You have chosen to open", nullptr));
        (void)DownloadOptionsDialog;
    } // retranslateUi

};

namespace Ui {
    class DownloadOptionsDialog: public Ui_DownloadOptionsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DOWNLOADOPTIONSDIALOG_H
