/********************************************************************************
** Form generated from reading UI file 'acceptlanguage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ACCEPTLANGUAGE_H
#define UI_ACCEPTLANGUAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AcceptLanguage
{
public:
    QGridLayout *gridLayout;
    QListWidget *listWidget;
    QVBoxLayout *verticalLayout;
    QPushButton *add;
    QPushButton *remove;
    QPushButton *up;
    QPushButton *down;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AcceptLanguage)
    {
        if (AcceptLanguage->objectName().isEmpty())
            AcceptLanguage->setObjectName("AcceptLanguage");
        AcceptLanguage->resize(464, 281);
        gridLayout = new QGridLayout(AcceptLanguage);
        gridLayout->setObjectName("gridLayout");
        listWidget = new QListWidget(AcceptLanguage);
        listWidget->setObjectName("listWidget");

        gridLayout->addWidget(listWidget, 0, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add = new QPushButton(AcceptLanguage);
        add->setObjectName("add");

        verticalLayout->addWidget(add);

        remove = new QPushButton(AcceptLanguage);
        remove->setObjectName("remove");

        verticalLayout->addWidget(remove);

        up = new QPushButton(AcceptLanguage);
        up->setObjectName("up");

        verticalLayout->addWidget(up);

        down = new QPushButton(AcceptLanguage);
        down->setObjectName("down");

        verticalLayout->addWidget(down);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(AcceptLanguage);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 2);


        retranslateUi(AcceptLanguage);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AcceptLanguage, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AcceptLanguage, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AcceptLanguage);
    } // setupUi

    void retranslateUi(QDialog *AcceptLanguage)
    {
        AcceptLanguage->setWindowTitle(QCoreApplication::translate("AcceptLanguage", "Preferred Languages", nullptr));
        add->setText(QCoreApplication::translate("AcceptLanguage", "Add...", nullptr));
        remove->setText(QCoreApplication::translate("AcceptLanguage", "Remove", nullptr));
        up->setText(QCoreApplication::translate("AcceptLanguage", "Up", nullptr));
        down->setText(QCoreApplication::translate("AcceptLanguage", "Down", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AcceptLanguage: public Ui_AcceptLanguage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ACCEPTLANGUAGE_H
