/****************************************************************************
** Meta object code from reading C++ file 'qmltab.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.0/src/lib/plugins/qml/api/tabs/qmltab.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmltab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6QmlTabE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlTab::qt_create_metaobjectdata<qt_meta_tag_ZN6QmlTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlTab",
        "titleChanged",
        "",
        "title",
        "pinnedChanged",
        "pinned",
        "loadingChanged",
        "loading",
        "mutedChanged",
        "muted",
        "restoredChanged",
        "restored",
        "playingChanged",
        "playing",
        "zoomLevelChanged",
        "zoomLevel",
        "backgroundActivityChanged",
        "navigationRequestAccepted",
        "QUrl",
        "url",
        "QWebEnginePage::NavigationType",
        "type",
        "isMainFrame",
        "detach",
        "setZoomLevel",
        "stop",
        "reload",
        "unload",
        "load",
        "zoomIn",
        "zoomOut",
        "zoomReset",
        "undo",
        "redo",
        "selectAll",
        "reloadBypassCache",
        "back",
        "forward",
        "printPage",
        "showSource",
        "sendPageByMail",
        "execJavaScript",
        "QVariant",
        "QJSValue",
        "value",
        "hitTestContent",
        "QmlWebHitTestResult*",
        "QPoint",
        "point",
        "index",
        "current",
        "browserWindow",
        "QmlWindow*",
        "loadingProgress",
        "backgroundActivity",
        "canGoBack",
        "canGoForward"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'pinnedChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'restoredChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'playingChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'zoomLevelChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'backgroundActivityChanged'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'navigationRequestAccepted'
        QtMocHelpers::SignalData<void(const QUrl &, QWebEnginePage::NavigationType, bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Method 'detach'
        QtMocHelpers::MethodData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setZoomLevel'
        QtMocHelpers::MethodData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Method 'stop'
        QtMocHelpers::MethodData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'reload'
        QtMocHelpers::MethodData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'unload'
        QtMocHelpers::MethodData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'load'
        QtMocHelpers::MethodData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'zoomIn'
        QtMocHelpers::MethodData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'zoomOut'
        QtMocHelpers::MethodData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'zoomReset'
        QtMocHelpers::MethodData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'undo'
        QtMocHelpers::MethodData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'redo'
        QtMocHelpers::MethodData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'selectAll'
        QtMocHelpers::MethodData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'reloadBypassCache'
        QtMocHelpers::MethodData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'back'
        QtMocHelpers::MethodData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'forward'
        QtMocHelpers::MethodData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'printPage'
        QtMocHelpers::MethodData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'showSource'
        QtMocHelpers::MethodData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'sendPageByMail'
        QtMocHelpers::MethodData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'execJavaScript'
        QtMocHelpers::MethodData<QVariant(const QJSValue &)>(41, 2, QMC::AccessPublic, 0x80000000 | 42, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Method 'hitTestContent'
        QtMocHelpers::MethodData<QmlWebHitTestResult *(const QPoint &)>(45, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { 0x80000000 | 47, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomLevel'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'index'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pinned'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muted'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'restored'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'current'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'playing'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'browserWindow'
        QtMocHelpers::PropertyData<QmlWindow*>(51, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loadingProgress'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'backgroundActivity'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'canGoBack'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'canGoForward'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlTab, qt_meta_tag_ZN6QmlTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlTab::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QmlTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QmlTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6QmlTabE_t>.metaTypes,
    nullptr
} };

void QmlTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->pinnedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->loadingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->restoredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->playingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->zoomLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->backgroundActivityChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->navigationRequestAccepted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWebEnginePage::NavigationType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 9: _t->detach(); break;
        case 10: _t->setZoomLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->stop(); break;
        case 12: _t->reload(); break;
        case 13: _t->unload(); break;
        case 14: _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->zoomIn(); break;
        case 16: _t->zoomOut(); break;
        case 17: _t->zoomReset(); break;
        case 18: _t->undo(); break;
        case 19: _t->redo(); break;
        case 20: _t->selectAll(); break;
        case 21: _t->reloadBypassCache(); break;
        case 22: _t->back(); break;
        case 23: _t->forward(); break;
        case 24: _t->printPage(); break;
        case 25: _t->showSource(); break;
        case 26: _t->sendPageByMail(); break;
        case 27: { QVariant _r = _t->execJavaScript((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 28: { QmlWebHitTestResult* _r = _t->hitTestContent((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QmlWebHitTestResult**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(const QString & )>(_a, &QmlTab::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(bool )>(_a, &QmlTab::pinnedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(bool )>(_a, &QmlTab::loadingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(bool )>(_a, &QmlTab::mutedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(bool )>(_a, &QmlTab::restoredChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(bool )>(_a, &QmlTab::playingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(int )>(_a, &QmlTab::zoomLevelChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(int )>(_a, &QmlTab::backgroundActivityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTab::*)(const QUrl & , QWebEnginePage::NavigationType , bool )>(_a, &QmlTab::navigationRequestAccepted, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QmlWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->url(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->zoomLevel(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->index(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->pinned(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->muted(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->restored(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->current(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->playing(); break;
        case 9: *reinterpret_cast<QmlWindow**>(_v) = _t->browserWindow(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->loadingProgress(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->backgroundActivity(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->canGoBack(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->canGoForward(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QmlTabE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void QmlTab::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QmlTab::pinnedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QmlTab::loadingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QmlTab::mutedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QmlTab::restoredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QmlTab::playingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QmlTab::zoomLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QmlTab::backgroundActivityChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QmlTab::navigationRequestAccepted(const QUrl & _t1, QWebEnginePage::NavigationType _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
