/********************************************************************************
** Form generated from reading UI file 'editsearchengine.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSEARCHENGINE_H
#define UI_EDITSEARCHENGINE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_EditSearchEngine
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *name;
    QLabel *label_2;
    QLineEdit *url;
    QLabel *label_3;
    QLineEdit *shortcut;
    QLabel *iconLabel;
    QFrame *editIconFrame;
    QHBoxLayout *editIconLayout;
    QLabel *icon;
    QPushButton *iconFromFile;
    QSpacerItem *horizontalSpacer;
    QLabel *label_4;
    QDialogButtonBox *buttonBox;
    QLabel *label_5;
    QLineEdit *postData;

    void setupUi(QDialog *EditSearchEngine)
    {
        if (EditSearchEngine->objectName().isEmpty())
            EditSearchEngine->setObjectName("EditSearchEngine");
        EditSearchEngine->resize(366, 204);
        formLayout = new QFormLayout(EditSearchEngine);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(EditSearchEngine);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        name = new QLineEdit(EditSearchEngine);
        name->setObjectName("name");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, name);

        label_2 = new QLabel(EditSearchEngine);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        url = new QLineEdit(EditSearchEngine);
        url->setObjectName("url");
        url->setText(QString::fromUtf8("http://"));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, url);

        label_3 = new QLabel(EditSearchEngine);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        shortcut = new QLineEdit(EditSearchEngine);
        shortcut->setObjectName("shortcut");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, shortcut);

        iconLabel = new QLabel(EditSearchEngine);
        iconLabel->setObjectName("iconLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, iconLabel);

        editIconFrame = new QFrame(EditSearchEngine);
        editIconFrame->setObjectName("editIconFrame");
        editIconLayout = new QHBoxLayout(editIconFrame);
        editIconLayout->setContentsMargins(0, 0, 0, 0);
        editIconLayout->setObjectName("editIconLayout");
        icon = new QLabel(editIconFrame);
        icon->setObjectName("icon");
        icon->setMinimumSize(QSize(16, 16));
        icon->setMaximumSize(QSize(16, 16));

        editIconLayout->addWidget(icon);

        iconFromFile = new QPushButton(editIconFrame);
        iconFromFile->setObjectName("iconFromFile");

        editIconLayout->addWidget(iconFromFile);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        editIconLayout->addItem(horizontalSpacer);


        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, editIconFrame);

        label_4 = new QLabel(EditSearchEngine);
        label_4->setObjectName("label_4");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, label_4);

        buttonBox = new QDialogButtonBox(EditSearchEngine);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, buttonBox);

        label_5 = new QLabel(EditSearchEngine);
        label_5->setObjectName("label_5");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        postData = new QLineEdit(EditSearchEngine);
        postData->setObjectName("postData");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, postData);


        retranslateUi(EditSearchEngine);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, EditSearchEngine, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EditSearchEngine, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(EditSearchEngine);
    } // setupUi

    void retranslateUi(QDialog *EditSearchEngine)
    {
        label->setText(QCoreApplication::translate("EditSearchEngine", "Name:", nullptr));
        label_2->setText(QCoreApplication::translate("EditSearchEngine", "Url:", nullptr));
        label_3->setText(QCoreApplication::translate("EditSearchEngine", "Shortcut:", nullptr));
        iconLabel->setText(QCoreApplication::translate("EditSearchEngine", "Icon:", nullptr));
        iconFromFile->setText(QCoreApplication::translate("EditSearchEngine", "Change...", nullptr));
        label_4->setText(QCoreApplication::translate("EditSearchEngine", "<b>Note: </b>%s in url or post data represent searched string", nullptr));
        label_5->setText(QCoreApplication::translate("EditSearchEngine", "Post Data:", nullptr));
        (void)EditSearchEngine;
    } // retranslateUi

};

namespace Ui {
    class EditSearchEngine: public Ui_EditSearchEngine {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EDITSEARCHENGINE_H
