/********************************************************************************
** Form generated from reading UI file 'PIM_settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PIM_SETTINGS_H
#define UI_PIM_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_PIM_Settings
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_tip;
    QGridLayout *gridLayout;
    QLabel *label_firstname;
    QLineEdit *pim_firstname;
    QLabel *label_lastname;
    QLineEdit *pim_lastname;
    QLabel *label_email;
    QLineEdit *pim_email;
    QLabel *label_phone;
    QLineEdit *pim_phone;
    QLabel *label_mobile;
    QLineEdit *pim_mobile;
    QLabel *label_address;
    QLineEdit *pim_address;
    QLabel *label_city;
    QLineEdit *pim_city;
    QLabel *label_zip;
    QLineEdit *pim_zip;
    QLabel *label_state;
    QLineEdit *pim_state;
    QLabel *label_country;
    QLineEdit *pim_country;
    QLabel *label_homepage;
    QLineEdit *pim_homepage;
    QLabel *label_special1;
    QLineEdit *pim_special1;
    QLabel *label_special2;
    QLineEdit *pim_special2;
    QLabel *label_special3;
    QLineEdit *pim_special3;
    QLabel *label_note;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PIM_Settings)
    {
        if (PIM_Settings->objectName().isEmpty())
            PIM_Settings->setObjectName("PIM_Settings");
        PIM_Settings->resize(539, 346);
        verticalLayout = new QVBoxLayout(PIM_Settings);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label_2 = new QLabel(PIM_Settings);
        label_2->setObjectName("label_2");
        label_2->setPixmap(QPixmap(QString::fromUtf8(":/PIM/data/PIM.png")));

        horizontalLayout->addWidget(label_2);

        label = new QLabel(PIM_Settings);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        label_tip = new QLabel(PIM_Settings);
        label_tip->setObjectName("label_tip");
        label_tip->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_tip);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_firstname = new QLabel(PIM_Settings);
        label_firstname->setObjectName("label_firstname");
        label_firstname->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_firstname, 0, 0, 1, 1);

        pim_firstname = new QLineEdit(PIM_Settings);
        pim_firstname->setObjectName("pim_firstname");

        gridLayout->addWidget(pim_firstname, 0, 1, 1, 1);

        label_lastname = new QLabel(PIM_Settings);
        label_lastname->setObjectName("label_lastname");
        label_lastname->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_lastname, 1, 0, 1, 1);

        pim_lastname = new QLineEdit(PIM_Settings);
        pim_lastname->setObjectName("pim_lastname");

        gridLayout->addWidget(pim_lastname, 1, 1, 1, 1);

        label_email = new QLabel(PIM_Settings);
        label_email->setObjectName("label_email");
        label_email->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_email, 2, 0, 1, 1);

        pim_email = new QLineEdit(PIM_Settings);
        pim_email->setObjectName("pim_email");

        gridLayout->addWidget(pim_email, 2, 1, 1, 1);

        label_phone = new QLabel(PIM_Settings);
        label_phone->setObjectName("label_phone");
        label_phone->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_phone, 3, 0, 1, 1);

        pim_phone = new QLineEdit(PIM_Settings);
        pim_phone->setObjectName("pim_phone");

        gridLayout->addWidget(pim_phone, 3, 1, 1, 1);

        label_mobile = new QLabel(PIM_Settings);
        label_mobile->setObjectName("label_mobile");
        label_mobile->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_mobile, 4, 0, 1, 1);

        pim_mobile = new QLineEdit(PIM_Settings);
        pim_mobile->setObjectName("pim_mobile");

        gridLayout->addWidget(pim_mobile, 4, 1, 1, 1);

        label_address = new QLabel(PIM_Settings);
        label_address->setObjectName("label_address");
        label_address->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_address, 5, 0, 1, 1);

        pim_address = new QLineEdit(PIM_Settings);
        pim_address->setObjectName("pim_address");

        gridLayout->addWidget(pim_address, 5, 1, 1, 1);

        label_city = new QLabel(PIM_Settings);
        label_city->setObjectName("label_city");
        label_city->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_city, 6, 0, 1, 1);

        pim_city = new QLineEdit(PIM_Settings);
        pim_city->setObjectName("pim_city");

        gridLayout->addWidget(pim_city, 6, 1, 1, 1);

        label_zip = new QLabel(PIM_Settings);
        label_zip->setObjectName("label_zip");
        label_zip->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_zip, 0, 2, 1, 1);

        pim_zip = new QLineEdit(PIM_Settings);
        pim_zip->setObjectName("pim_zip");

        gridLayout->addWidget(pim_zip, 0, 3, 1, 1);

        label_state = new QLabel(PIM_Settings);
        label_state->setObjectName("label_state");
        label_state->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_state, 1, 2, 1, 1);

        pim_state = new QLineEdit(PIM_Settings);
        pim_state->setObjectName("pim_state");

        gridLayout->addWidget(pim_state, 1, 3, 1, 1);

        label_country = new QLabel(PIM_Settings);
        label_country->setObjectName("label_country");
        label_country->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_country, 2, 2, 1, 1);

        pim_country = new QLineEdit(PIM_Settings);
        pim_country->setObjectName("pim_country");

        gridLayout->addWidget(pim_country, 2, 3, 1, 1);

        label_homepage = new QLabel(PIM_Settings);
        label_homepage->setObjectName("label_homepage");
        label_homepage->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_homepage, 3, 2, 1, 1);

        pim_homepage = new QLineEdit(PIM_Settings);
        pim_homepage->setObjectName("pim_homepage");

        gridLayout->addWidget(pim_homepage, 3, 3, 1, 1);

        label_special1 = new QLabel(PIM_Settings);
        label_special1->setObjectName("label_special1");
        label_special1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_special1, 4, 2, 1, 1);

        pim_special1 = new QLineEdit(PIM_Settings);
        pim_special1->setObjectName("pim_special1");

        gridLayout->addWidget(pim_special1, 4, 3, 1, 1);

        label_special2 = new QLabel(PIM_Settings);
        label_special2->setObjectName("label_special2");
        label_special2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_special2, 5, 2, 1, 1);

        pim_special2 = new QLineEdit(PIM_Settings);
        pim_special2->setObjectName("pim_special2");

        gridLayout->addWidget(pim_special2, 5, 3, 1, 1);

        label_special3 = new QLabel(PIM_Settings);
        label_special3->setObjectName("label_special3");
        label_special3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_special3, 6, 2, 1, 1);

        pim_special3 = new QLineEdit(PIM_Settings);
        pim_special3->setObjectName("pim_special3");

        gridLayout->addWidget(pim_special3, 6, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        label_note = new QLabel(PIM_Settings);
        label_note->setObjectName("label_note");

        verticalLayout->addWidget(label_note);

        buttonBox = new QDialogButtonBox(PIM_Settings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(PIM_Settings);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, PIM_Settings, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, PIM_Settings, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(PIM_Settings);
    } // setupUi

    void retranslateUi(QDialog *PIM_Settings)
    {
        PIM_Settings->setWindowTitle(QCoreApplication::translate("PIM_Settings", "PIM Settings", nullptr));
        label->setText(QCoreApplication::translate("PIM_Settings", "<h2>Personal Information Manager</h2>", nullptr));
        label_tip->setText(QCoreApplication::translate("PIM_Settings", "Your personal information that will be used on webpages.", nullptr));
        label_firstname->setText(QCoreApplication::translate("PIM_Settings", "First Name:", nullptr));
        label_lastname->setText(QCoreApplication::translate("PIM_Settings", "Last Name:", nullptr));
        label_email->setText(QCoreApplication::translate("PIM_Settings", "E-mail:", nullptr));
        label_phone->setText(QCoreApplication::translate("PIM_Settings", "Phone:", nullptr));
        label_mobile->setText(QCoreApplication::translate("PIM_Settings", "Mobile Phone:", nullptr));
        label_address->setText(QCoreApplication::translate("PIM_Settings", "Address:", nullptr));
        label_city->setText(QCoreApplication::translate("PIM_Settings", "City:", nullptr));
        label_zip->setText(QCoreApplication::translate("PIM_Settings", "ZIP Code:", nullptr));
        label_state->setText(QCoreApplication::translate("PIM_Settings", "State/Region:", nullptr));
        label_country->setText(QCoreApplication::translate("PIM_Settings", "Country:", nullptr));
        label_homepage->setText(QCoreApplication::translate("PIM_Settings", "Home Page:", nullptr));
        label_special1->setText(QCoreApplication::translate("PIM_Settings", "Custom 1:", nullptr));
        label_special2->setText(QCoreApplication::translate("PIM_Settings", "Custom 2:", nullptr));
        label_special3->setText(QCoreApplication::translate("PIM_Settings", "Custom 3:", nullptr));
        label_note->setText(QCoreApplication::translate("PIM_Settings", "<b>Note:</b> Press Ctrl+ENTER to autofill form fields for which Falkon finds personal entries.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PIM_Settings: public Ui_PIM_Settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PIM_SETTINGS_H
