/********************************************************************************
** Form generated from reading UI file 'bookmarksimportdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKSIMPORTDIALOG_H
#define UI_BOOKMARKSIMPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BookmarksImportDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QStackedWidget *stackedWidget;
    QWidget *browserPage;
    QGridLayout *gridLayout;
    QListWidget *browserList;
    QLabel *label_2;
    QWidget *filePage;
    QGridLayout *gridLayout_2;
    QLabel *standardDirLabel;
    QLabel *importingFromLabel;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *fileLine;
    QPushButton *chooseFile;
    QSpacerItem *verticalSpacer_4;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer;
    QLabel *fileText1;
    QSpacerItem *verticalSpacer_3;
    QLabel *iconLabel;
    QWidget *finalPage;
    QVBoxLayout *verticalLayout_3;
    QTreeView *treeView;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *backButton;
    QPushButton *nextButton;
    QDialogButtonBox *cancelButton;

    void setupUi(QDialog *BookmarksImportDialog)
    {
        if (BookmarksImportDialog->objectName().isEmpty())
            BookmarksImportDialog->setObjectName("BookmarksImportDialog");
        BookmarksImportDialog->resize(550, 370);
        BookmarksImportDialog->setMinimumSize(QSize(550, 350));
        verticalLayout = new QVBoxLayout(BookmarksImportDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(BookmarksImportDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        stackedWidget = new QStackedWidget(BookmarksImportDialog);
        stackedWidget->setObjectName("stackedWidget");
        browserPage = new QWidget();
        browserPage->setObjectName("browserPage");
        gridLayout = new QGridLayout(browserPage);
        gridLayout->setObjectName("gridLayout");
        browserList = new QListWidget(browserPage);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/browsers/firefox.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(browserList);
        __qlistwidgetitem->setText(QString::fromUtf8("Mozilla Firefox"));
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/browsers/chrome.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(browserList);
        __qlistwidgetitem1->setText(QString::fromUtf8("Google Chrome"));
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/browsers/opera.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(browserList);
        __qlistwidgetitem2->setText(QString::fromUtf8("Opera"));
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/icons/browsers/ie.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(browserList);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/icons/browsers/html.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(browserList);
        __qlistwidgetitem4->setIcon(icon4);
        browserList->setObjectName("browserList");
        browserList->setIconSize(QSize(48, 48));

        gridLayout->addWidget(browserList, 1, 1, 1, 1);

        label_2 = new QLabel(browserPage);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 3);

        stackedWidget->addWidget(browserPage);
        filePage = new QWidget();
        filePage->setObjectName("filePage");
        gridLayout_2 = new QGridLayout(filePage);
        gridLayout_2->setObjectName("gridLayout_2");
        standardDirLabel = new QLabel(filePage);
        standardDirLabel->setObjectName("standardDirLabel");
        standardDirLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(standardDirLabel, 4, 1, 1, 1);

        importingFromLabel = new QLabel(filePage);
        importingFromLabel->setObjectName("importingFromLabel");

        gridLayout_2->addWidget(importingFromLabel, 0, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        fileLine = new QLineEdit(filePage);
        fileLine->setObjectName("fileLine");
        fileLine->setEnabled(false);

        horizontalLayout_2->addWidget(fileLine);

        chooseFile = new QPushButton(filePage);
        chooseFile->setObjectName("chooseFile");

        horizontalLayout_2->addWidget(chooseFile);


        gridLayout_2->addLayout(horizontalLayout_2, 7, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_4, 6, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_2, 3, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer, 1, 1, 1, 1);

        fileText1 = new QLabel(filePage);
        fileText1->setObjectName("fileText1");
        fileText1->setWordWrap(true);

        gridLayout_2->addWidget(fileText1, 2, 0, 1, 2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_3, 8, 0, 1, 1);

        iconLabel = new QLabel(filePage);
        iconLabel->setObjectName("iconLabel");
        iconLabel->setMinimumSize(QSize(48, 48));
        iconLabel->setMaximumSize(QSize(48, 48));

        gridLayout_2->addWidget(iconLabel, 0, 0, 1, 1);

        stackedWidget->addWidget(filePage);
        finalPage = new QWidget();
        finalPage->setObjectName("finalPage");
        verticalLayout_3 = new QVBoxLayout(finalPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        treeView = new QTreeView(finalPage);
        treeView->setObjectName("treeView");
        treeView->header()->setStretchLastSection(true);

        verticalLayout_3->addWidget(treeView);

        stackedWidget->addWidget(finalPage);

        verticalLayout->addWidget(stackedWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        backButton = new QPushButton(BookmarksImportDialog);
        backButton->setObjectName("backButton");
        backButton->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(backButton->sizePolicy().hasHeightForWidth());
        backButton->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(backButton);

        nextButton = new QPushButton(BookmarksImportDialog);
        nextButton->setObjectName("nextButton");
        sizePolicy.setHeightForWidth(nextButton->sizePolicy().hasHeightForWidth());
        nextButton->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(nextButton);

        cancelButton = new QDialogButtonBox(BookmarksImportDialog);
        cancelButton->setObjectName("cancelButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cancelButton->sizePolicy().hasHeightForWidth());
        cancelButton->setSizePolicy(sizePolicy1);
        cancelButton->setStandardButtons(QDialogButtonBox::Cancel);

        horizontalLayout->addWidget(cancelButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(BookmarksImportDialog);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BookmarksImportDialog);
    } // setupUi

    void retranslateUi(QDialog *BookmarksImportDialog)
    {
        BookmarksImportDialog->setWindowTitle(QCoreApplication::translate("BookmarksImportDialog", "Import Bookmarks", nullptr));
        label->setText(QCoreApplication::translate("BookmarksImportDialog", "<b>Import Bookmarks</b>", nullptr));

        const bool __sortingEnabled = browserList->isSortingEnabled();
        browserList->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = browserList->item(3);
        ___qlistwidgetitem->setText(QCoreApplication::translate("BookmarksImportDialog", "Internet Explorer", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = browserList->item(4);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("BookmarksImportDialog", "Html File", nullptr));
        browserList->setSortingEnabled(__sortingEnabled);

        label_2->setText(QCoreApplication::translate("BookmarksImportDialog", "Choose from which you want to import bookmarks:", nullptr));
        chooseFile->setText(QCoreApplication::translate("BookmarksImportDialog", "Choose...", nullptr));
        backButton->setText(QCoreApplication::translate("BookmarksImportDialog", "< Back", nullptr));
        nextButton->setText(QCoreApplication::translate("BookmarksImportDialog", "Next >", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BookmarksImportDialog: public Ui_BookmarksImportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOOKMARKSIMPORTDIALOG_H
