

#ifndef SBK_PYFALKON_PYTHON_H
#define SBK_PYFALKON_PYTHON_H

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtwebenginecore_python.h>
#include <pyside6_qtcore_python.h>
#include <pyside6_qtgui_python.h>
#include <pyside6_qtnetwork_python.h>
#include <pyside6_qtprintsupport_python.h>
#include <pyside6_qtwidgets_python.h>
#include <pyside6_qtwebchannel_python.h>
#include <pyside6_qtwebenginewidgets_python.h>
#include <pyside6_qtsql_python.h>

// Bound library includes
#include <abstractbuttoninterface.h>
#include <autofill.h>
#include <autosaver.h>
#include <bookmarkitem.h>
#include <bookmarks.h>
#include <bookmarksmodel.h>
#include <bookmarkstools.h>
#include <browserwindow.h>
#include <checkboxdialog.h>
#include <clickablelabel.h>
#include <combotabbar.h>
#include <cookiejar.h>
#include <cookiemanager.h>
#include <datapaths.h>
#include <delayedfilewatcher.h>
#include <desktopfile.h>
#include <desktopnotificationsfactory.h>
#include <downloaditem.h>
#include <downloadmanager.h>
#include <enhancedmenu.h>
#include <history.h>
#include <historyitem.h>
#include <historymodel.h>
#include <iconprovider.h>
#include <javascript/externaljsobject.h>
#include <lineedit.h>
#include <loadrequest.h>
#include <locationbar.h>
#include <mainapplication.h>
#include <navigationbar.h>
#include <networkmanager.h>
#include <passwordbackends/passwordbackend.h>
#include <passwordmanager.h>
#include <plugininterface.h>
#include <pluginproxy.h>
#include <plugins.h>
#include <qtsingleapplication/qtsingleapplication.h>
#include <qzcommon.h>
#include <qzsettings.h>
#include <qztools.h>
#include <schemehandlers/extensionschemehandler.h>
#include <searchenginesdialog.h>
#include <searchenginesmanager.h>
#include <searchtoolbar.h>
#include <settings.h>
#include <sidebar.h>
#include <sidebarinterface.h>
#include <sitesettingsmanager.h>
#include <sqldatabase.h>
#include <squeezelabelv1.h>
#include <squeezelabelv2.h>
#include <statusbar.h>
#include <tabbar.h>
#include <tabbedwebview.h>
#include <tabcontextmenu.h>
#include <tabicon.h>
#include <tabmodel.h>
#include <tabmrumodel.h>
#include <tabstackedwidget.h>
#include <tabtreemodel.h>
#include <tabwidget.h>
#include <toolbutton.h>
#include <urlinterceptor.h>
#include <webhittestresult.h>
#include <webinspector.h>
#include <webpage.h>
#include <webtab.h>
#include <webview.h>
#include <wheelhelper.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <qjsonobject.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qvariant.h>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_AbstractButtonInterface_IDX                          = 0,
    SBK_AbstractButtonInterface_ClickController_IDX          = 1,
    SBK_Action_IDX                                           = 2,
    SBK_AutoFill_IDX                                         = 3,
    SBK_AutoSaver_IDX                                        = 4,
    SBK_BookmarkItem_Type_IDX                                = 6,
    SBK_BookmarkItem_IDX                                     = 5,
    SBK_Bookmarks_IDX                                        = 7,
    SBK_BookmarksFoldersButton_IDX                           = 8,
    SBK_BookmarksFoldersMenu_IDX                             = 9,
    SBK_BookmarksModel_Roles_IDX                             = 11,
    SBK_BookmarksModel_IDX                                   = 10,
    SBK_BookmarksTools_IDX                                   = 12,
    SBK_BrowserWindow_IDX                                    = 13,
    SBK_CheckBoxDialog_IDX                                   = 14,
    SBK_ClickableLabel_IDX                                   = 15,
    SBK_ComboTabBar_SizeType_IDX                             = 18,
    SBK_ComboTabBar_DropIndicatorPosition_IDX                = 17,
    SBK_ComboTabBar_IDX                                      = 16,
    SBK_CookieJar_IDX                                        = 19,
    SBK_CookieManager_IDX                                    = 20,
    SBK_DataPaths_Path_IDX                                   = 22,
    SBK_DataPaths_IDX                                        = 21,
    SBK_DelayedFileWatcher_IDX                               = 23,
    SBK_DesktopFile_IDX                                      = 24,
    SBK_DesktopNotificationsFactory_Type_IDX                 = 26,
    SBK_DesktopNotificationsFactory_IDX                      = 25,
    SBK_DownloadItem_IDX                                     = 27,
    SBK_DownloadManager_DownloadOption_IDX                   = 30,
    SBK_DownloadManager_IDX                                  = 28,
    SBK_DownloadManager_DownloadInfo_IDX                     = 29,
    SBK_ExtensionSchemeHandler_IDX                           = 31,
    SBK_ExternalJsObject_IDX                                 = 32,
    SBK_History_IDX                                          = 33,
    SBK_History_HistoryEntry_IDX                             = 34,
    SBK_HistoryItem_IDX                                      = 35,
    SBK_HistoryModel_Roles_IDX                               = 37,
    SBK_HistoryModel_IDX                                     = 36,
    SBK_IconProvider_IDX                                     = 38,
    SBK_LineEdit_WidgetPosition_IDX                          = 41,
    SBK_LineEdit_EditAction_IDX                              = 40,
    SBK_LineEdit_IDX                                         = 39,
    SBK_LoadRequest_Operation_IDX                            = 43,
    SBK_LoadRequest_IDX                                      = 42,
    SBK_LocationBar_IDX                                      = 44,
    SBK_LocationBar_LoadAction_Type_IDX                      = 46,
    SBK_LocationBar_LoadAction_IDX                           = 45,
    SBK_MainApplication_AfterLaunch_IDX                      = 48,
    SBK_MainApplication_IDX                                  = 47,
    SBK_Menu_IDX                                             = 49,
    SBK_NavigationBar_IDX                                    = 50,
    SBK_NetworkManager_IDX                                   = 51,
    SBK_PageFormData_IDX                                     = 52,
    SBK_PasswordBackend_IDX                                  = 53,
    SBK_PasswordEntry_IDX                                    = 54,
    SBK_PasswordManager_IDX                                  = 55,
    SBK_PluginInterface_InitState_IDX                        = 57,
    SBK_PluginInterface_IDX                                  = 56,
    SBK_PluginProxy_EventHandlerType_IDX                     = 59,
    SBK_PluginProxy_IDX                                      = 58,
    SBK_PluginSpec_IDX                                       = 60,
    SBK_Plugins_IDX                                          = 61,
    SBK_Plugins_Plugin_Type_IDX                              = 63,
    SBK_Plugins_Plugin_IDX                                   = 62,
    SBK_QtSingleApplication_IDX                              = 66,
    SBK_Qz_BrowserWindowType_IDX                             = 68,
    SBK_Qz_CommandLineAction_IDX                             = 70,
    SBK_Qz_ObjectName_IDX                                    = 72,
    SBK_Qz_NewTabPositionFlag_IDX                            = 71,
    SBK_QFlags_Qz_NewTabPositionFlag_IDX                     = 64,
    SBK_Qz_ColorScheme_IDX                                   = 69,
    SBK_PyFalkonQz_IDX                                       = 67,
    SBK_QzSettings_IDX                                       = 73,
    SBK_QzTools_IDX                                          = 74,
    SBK_SearchEnginesDialog_IDX                              = 75,
    SBK_SearchEnginesManager_IDX                             = 76,
    SBK_SearchEnginesManager_Engine_IDX                      = 77,
    SBK_SearchToolBar_IDX                                    = 78,
    SBK_Settings_IDX                                         = 79,
    SBK_SideBarInterface_IDX                                 = 80,
    SBK_SideBarManager_IDX                                   = 81,
    SBK_SideWidget_IDX                                       = 82,
    SBK_SiteSettingsManager_Permission_IDX                   = 85,
    SBK_SiteSettingsManager_PageOptions_IDX                  = 84,
    SBK_SiteSettingsManager_IDX                              = 83,
    SBK_SiteSettingsManager_SiteSettings_IDX                 = 86,
    SBK_SqlDatabase_IDX                                      = 87,
    SBK_SqlQueryJob_IDX                                      = 88,
    SBK_SqueezeLabelV1_IDX                                   = 89,
    SBK_SqueezeLabelV2_IDX                                   = 90,
    SBK_StatusBar_IDX                                        = 91,
    SBK_TabBar_IDX                                           = 92,
    SBK_TabContextMenu_Option_IDX                            = 94,
    SBK_QFlags_TabContextMenu_Option_IDX                     = 65,
    SBK_TabContextMenu_IDX                                   = 93,
    SBK_TabIcon_IDX                                          = 95,
    SBK_TabIcon_Data_IDX                                     = 96,
    SBK_TabModel_Roles_IDX                                   = 98,
    SBK_TabModel_IDX                                         = 97,
    SBK_TabMruModel_IDX                                      = 99,
    SBK_TabStackedWidget_IDX                                 = 100,
    SBK_TabTreeModel_IDX                                     = 101,
    SBK_TabWidget_IDX                                        = 102,
    SBK_TabbedWebView_IDX                                    = 103,
    SBK_ToolButton_IDX                                       = 104,
    SBK_UrlInterceptor_IDX                                   = 105,
    SBK_WebHitTestResult_IDX                                 = 106,
    SBK_WebInspector_IDX                                     = 107,
    SBK_WebPage_JsWorld_IDX                                  = 109,
    SBK_WebPage_IDX                                          = 108,
    SBK_WebTab_AddChildBehavior_IDX                          = 111,
    SBK_WebTab_IDX                                           = 110,
    SBK_WebView_IDX                                          = 112,
    SBK_WheelHelper_Direction_IDX                            = 114,
    SBK_WheelHelper_IDX                                      = 113,
    SBK_PyFalkon_IDX_COUNT                                   = 115,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkPyFalkonTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkPyFalkonModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkPyFalkonTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_PYFALKON_QLIST_INT_IDX                               = 0, // QList<int>
    SBK_PYFALKON_QLIST_WEBTABPTR_IDX                         = 1, // QList<WebTab*>
    SBK_PYFALKON_QHASH_QSTRING_QVARIANT_IDX                  = 2, // QHash<QString,QVariant>
    SBK_PYFALKON_STD_PAIR_BOOL_QSTRING_IDX                   = 3, // std::pair<bool,QString>
    SBK_PYFALKON_QMAP_QSTRING_QVARIANT_IDX                   = 4, // QMap<QString,QVariant>
    SBK_PYFALKON_QMAP_INT_QVARIANT_IDX                       = 5, // QMap<int,QVariant>
    SBK_PYFALKON_QLIST_QMODELINDEX_IDX                       = 6, // QList<QModelIndex>
    SBK_PYFALKON_QHASH_INT_QBYTEARRAY_IDX                    = 7, // QHash<int,QByteArray>
    SBK_PYFALKON_QLIST_QSQLRECORD_IDX                        = 8, // QList<QSqlRecord>
    SBK_PYFALKON_QMAP_QSTRING_SITESETTINGSMANAGER_PERMISSION_IDX = 9, // QMap<QString,SiteSettingsManager::Permission>
    SBK_PYFALKON_QLIST_QWEBENGINESETTINGS_WEBATTRIBUTE_IDX   = 10, // QList<QWebEngineSettings::WebAttribute>
    SBK_PYFALKON_QLIST_QWEBENGINEPAGE_FEATURE_IDX            = 11, // QList<QWebEnginePage::Feature>
    SBK_PYFALKON_QHASH_QWEBENGINESETTINGS_WEBATTRIBUTE_BOOL_IDX = 12, // QHash<QWebEngineSettings::WebAttribute,bool>
    SBK_PYFALKON_QMAP_QWEBENGINESETTINGS_WEBATTRIBUTE_SITESETTINGSMANAGER_PERMISSION_IDX = 13, // QMap<QWebEngineSettings::WebAttribute,SiteSettingsManager::Permission>
    SBK_PYFALKON_QMAP_QWEBENGINEPAGE_FEATURE_SITESETTINGSMANAGER_PERMISSION_IDX = 14, // QMap<QWebEnginePage::Feature,SiteSettingsManager::Permission>
    SBK_PYFALKON_QLIST_SEARCHENGINESMANAGER_ENGINE_IDX       = 15, // QList<SearchEnginesManager::Engine>
    SBK_PYFALKON_QLIST_PLUGINS_PLUGIN_IDX                    = 16, // QList<Plugins::Plugin>
    SBK_PYFALKON_QLIST_PLUGININTERFACEPTR_IDX                = 17, // QList<PluginInterface*>
    SBK_PYFALKON_QHASH_QSTRING_PASSWORDBACKENDPTR_IDX        = 18, // QHash<QString,PasswordBackend*>
    SBK_PYFALKON_QLIST_PASSWORDENTRY_IDX                     = 19, // QList<PasswordEntry>
    SBK_PYFALKON_QHASH_QSTRING_QWEBENGINECERTIFICATEERROR_TYPE_IDX = 20, // QHash<QString,QWebEngineCertificateError::Type>
    SBK_PYFALKON_QLIST_QURL_IDX                              = 21, // QList<QUrl>
    SBK_PYFALKON_QLIST_BROWSERWINDOWPTR_IDX                  = 22, // QList<BrowserWindow*>
    SBK_PYFALKON_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX           = 23, // QList<QTextLayout::FormatRange>
    SBK_PYFALKON_QLIST_QPERSISTENTMODELINDEX_IDX             = 24, // QList<QPersistentModelIndex>
    SBK_PYFALKON_QLIST_HISTORY_HISTORYENTRY_IDX              = 25, // QList<History::HistoryEntry>
    SBK_PYFALKON_QLIST_QNETWORKCOOKIE_IDX                    = 26, // QList<QNetworkCookie>
    SBK_PYFALKON_QLIST_QACTIONPTR_IDX                        = 27, // QList<QAction*>
    SBK_PYFALKON_QLIST_QVARIANT_IDX                          = 28, // QList<QVariant>
    SBK_PYFALKON_QLIST_BOOKMARKITEMPTR_IDX                   = 29, // QList<BookmarkItem*>
    SBK_PYFALKON_QLIST_QSTRING_IDX                           = 30, // QList<QString>
    SBK_PYFALKON_CONVERTERS_IDX_COUNT                        = 31,
};

// Converter indices
enum : int {
    SBK_PyFalkon_QList_int_IDX                               = 0, // QList<int>
    SBK_PyFalkon_QList_WebTabPTR_IDX                         = 1, // QList<WebTab*>
    SBK_PyFalkon_QHash_QString_QVariant_IDX                  = 2, // QHash<QString,QVariant>
    SBK_PyFalkon_std_pair_bool_QString_IDX                   = 3, // std::pair<bool,QString>
    SBK_PyFalkon_QMap_QString_QVariant_IDX                   = 4, // QMap<QString,QVariant>
    SBK_PyFalkon_QMap_int_QVariant_IDX                       = 5, // QMap<int,QVariant>
    SBK_PyFalkon_QList_QModelIndex_IDX                       = 6, // QList<QModelIndex>
    SBK_PyFalkon_QHash_int_QByteArray_IDX                    = 7, // QHash<int,QByteArray>
    SBK_PyFalkon_QList_QSqlRecord_IDX                        = 8, // QList<QSqlRecord>
    SBK_PyFalkon_QMap_QString_SiteSettingsManager_Permission_IDX = 9, // QMap<QString,SiteSettingsManager::Permission>
    SBK_PyFalkon_QList_QWebEngineSettings_WebAttribute_IDX   = 10, // QList<QWebEngineSettings::WebAttribute>
    SBK_PyFalkon_QList_QWebEnginePage_Feature_IDX            = 11, // QList<QWebEnginePage::Feature>
    SBK_PyFalkon_QHash_QWebEngineSettings_WebAttribute_bool_IDX = 12, // QHash<QWebEngineSettings::WebAttribute,bool>
    SBK_PyFalkon_QMap_QWebEngineSettings_WebAttribute_SiteSettingsManager_Permission_IDX = 13, // QMap<QWebEngineSettings::WebAttribute,SiteSettingsManager::Permission>
    SBK_PyFalkon_QMap_QWebEnginePage_Feature_SiteSettingsManager_Permission_IDX = 14, // QMap<QWebEnginePage::Feature,SiteSettingsManager::Permission>
    SBK_PyFalkon_QList_SearchEnginesManager_Engine_IDX       = 15, // QList<SearchEnginesManager::Engine>
    SBK_PyFalkon_QList_Plugins_Plugin_IDX                    = 16, // QList<Plugins::Plugin>
    SBK_PyFalkon_QList_PluginInterfacePTR_IDX                = 17, // QList<PluginInterface*>
    SBK_PyFalkon_QHash_QString_PasswordBackendPTR_IDX        = 18, // QHash<QString,PasswordBackend*>
    SBK_PyFalkon_QList_PasswordEntry_IDX                     = 19, // QList<PasswordEntry>
    SBK_PyFalkon_QHash_QString_QWebEngineCertificateError_Type_IDX = 20, // QHash<QString,QWebEngineCertificateError::Type>
    SBK_PyFalkon_QList_QUrl_IDX                              = 21, // QList<QUrl>
    SBK_PyFalkon_QList_BrowserWindowPTR_IDX                  = 22, // QList<BrowserWindow*>
    SBK_PyFalkon_QList_QTextLayout_FormatRange_IDX           = 23, // QList<QTextLayout::FormatRange>
    SBK_PyFalkon_QList_QPersistentModelIndex_IDX             = 24, // QList<QPersistentModelIndex>
    SBK_PyFalkon_QList_History_HistoryEntry_IDX              = 25, // QList<History::HistoryEntry>
    SBK_PyFalkon_QList_QNetworkCookie_IDX                    = 26, // QList<QNetworkCookie>
    SBK_PyFalkon_QList_QActionPTR_IDX                        = 27, // QList<QAction*>
    SBK_PyFalkon_QList_QVariant_IDX                          = 28, // QList<QVariant>
    SBK_PyFalkon_QList_BookmarkItemPTR_IDX                   = 29, // QList<BookmarkItem*>
    SBK_PyFalkon_QList_QString_IDX                           = 30, // QList<QString>
    SBK_PyFalkon_CONVERTERS_IDX_COUNT                        = 31,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::AbstractButtonInterface >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_AbstractButtonInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::AbstractButtonInterface::ClickController >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_AbstractButtonInterface_ClickController_IDX]); }
template<> inline PyTypeObject *SbkType< ::Action >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Action_IDX]); }
template<> inline PyTypeObject *SbkType< ::AutoFill >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_AutoFill_IDX]); }
template<> inline PyTypeObject *SbkType< ::AutoSaver >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_AutoSaver_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarkItem::Type >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarkItem_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarkItem >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarkItem_IDX]); }
template<> inline PyTypeObject *SbkType< ::Bookmarks >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Bookmarks_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarksFoldersButton >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarksFoldersButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarksFoldersMenu >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarksFoldersMenu_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarksModel::Roles >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarksModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarksModel >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarksModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::BookmarksTools >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BookmarksTools_IDX]); }
template<> inline PyTypeObject *SbkType< ::BrowserWindow >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_BrowserWindow_IDX]); }
template<> inline PyTypeObject *SbkType< ::CheckBoxDialog >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_CheckBoxDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::ClickableLabel >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ClickableLabel_IDX]); }
template<> inline PyTypeObject *SbkType< ::ComboTabBar::SizeType >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ComboTabBar_SizeType_IDX]); }
template<> inline PyTypeObject *SbkType< ::ComboTabBar::DropIndicatorPosition >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ComboTabBar_DropIndicatorPosition_IDX]); }
template<> inline PyTypeObject *SbkType< ::ComboTabBar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ComboTabBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::CookieJar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_CookieJar_IDX]); }
template<> inline PyTypeObject *SbkType< ::CookieManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_CookieManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::DataPaths::Path >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DataPaths_Path_IDX]); }
template<> inline PyTypeObject *SbkType< ::DataPaths >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DataPaths_IDX]); }
template<> inline PyTypeObject *SbkType< ::DelayedFileWatcher >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DelayedFileWatcher_IDX]); }
template<> inline PyTypeObject *SbkType< ::DesktopFile >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DesktopFile_IDX]); }
template<> inline PyTypeObject *SbkType< ::DesktopNotificationsFactory::Type >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DesktopNotificationsFactory_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::DesktopNotificationsFactory >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DesktopNotificationsFactory_IDX]); }
template<> inline PyTypeObject *SbkType< ::DownloadItem >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DownloadItem_IDX]); }
template<> inline PyTypeObject *SbkType< ::DownloadManager::DownloadOption >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DownloadManager_DownloadOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::DownloadManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DownloadManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::DownloadManager::DownloadInfo >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_DownloadManager_DownloadInfo_IDX]); }
template<> inline PyTypeObject *SbkType< ::ExtensionSchemeHandler >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ExtensionSchemeHandler_IDX]); }
template<> inline PyTypeObject *SbkType< ::ExternalJsObject >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ExternalJsObject_IDX]); }
template<> inline PyTypeObject *SbkType< ::History >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_History_IDX]); }
template<> inline PyTypeObject *SbkType< ::History::HistoryEntry >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_History_HistoryEntry_IDX]); }
template<> inline PyTypeObject *SbkType< ::HistoryItem >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_HistoryItem_IDX]); }
template<> inline PyTypeObject *SbkType< ::HistoryModel::Roles >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_HistoryModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::HistoryModel >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_HistoryModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::IconProvider >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_IconProvider_IDX]); }
template<> inline PyTypeObject *SbkType< ::LineEdit::WidgetPosition >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LineEdit_WidgetPosition_IDX]); }
template<> inline PyTypeObject *SbkType< ::LineEdit::EditAction >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LineEdit_EditAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::LineEdit >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LineEdit_IDX]); }
template<> inline PyTypeObject *SbkType< ::LoadRequest::Operation >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LoadRequest_Operation_IDX]); }
template<> inline PyTypeObject *SbkType< ::LoadRequest >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LoadRequest_IDX]); }
template<> inline PyTypeObject *SbkType< ::LocationBar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LocationBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::LocationBar::LoadAction::Type >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LocationBar_LoadAction_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::LocationBar::LoadAction >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_LocationBar_LoadAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::MainApplication::AfterLaunch >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_MainApplication_AfterLaunch_IDX]); }
template<> inline PyTypeObject *SbkType< ::MainApplication >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_MainApplication_IDX]); }
template<> inline PyTypeObject *SbkType< ::Menu >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Menu_IDX]); }
template<> inline PyTypeObject *SbkType< ::NavigationBar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_NavigationBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::NetworkManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_NetworkManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::PageFormData >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PageFormData_IDX]); }
template<> inline PyTypeObject *SbkType< ::PasswordBackend >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PasswordBackend_IDX]); }
template<> inline PyTypeObject *SbkType< ::PasswordEntry >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PasswordEntry_IDX]); }
template<> inline PyTypeObject *SbkType< ::PasswordManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PasswordManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::PluginInterface::InitState >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PluginInterface_InitState_IDX]); }
template<> inline PyTypeObject *SbkType< ::PluginInterface >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PluginInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::PluginProxy::EventHandlerType >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PluginProxy_EventHandlerType_IDX]); }
template<> inline PyTypeObject *SbkType< ::PluginProxy >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PluginProxy_IDX]); }
template<> inline PyTypeObject *SbkType< ::PluginSpec >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_PluginSpec_IDX]); }
template<> inline PyTypeObject *SbkType< ::Plugins >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Plugins_IDX]); }
template<> inline PyTypeObject *SbkType< ::Plugins::Plugin::Type >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Plugins_Plugin_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::Plugins::Plugin >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Plugins_Plugin_IDX]); }
template<> inline PyTypeObject *SbkType< ::QtSingleApplication >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_QtSingleApplication_IDX]); }
template<> inline PyTypeObject *SbkType< ::Qz::BrowserWindowType >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Qz_BrowserWindowType_IDX]); }
template<> inline PyTypeObject *SbkType< ::Qz::CommandLineAction >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Qz_CommandLineAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::Qz::ObjectName >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Qz_ObjectName_IDX]); }
template<> inline PyTypeObject *SbkType< ::Qz::NewTabPositionFlag >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Qz_NewTabPositionFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<Qz::NewTabPositionFlag> >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_QFlags_Qz_NewTabPositionFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::Qz::ColorScheme >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Qz_ColorScheme_IDX]); }
template<> inline PyTypeObject *SbkType< ::QzSettings >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_QzSettings_IDX]); }
template<> inline PyTypeObject *SbkType< ::QzTools >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_QzTools_IDX]); }
template<> inline PyTypeObject *SbkType< ::SearchEnginesDialog >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SearchEnginesDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::SearchEnginesManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SearchEnginesManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::SearchEnginesManager::Engine >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SearchEnginesManager_Engine_IDX]); }
template<> inline PyTypeObject *SbkType< ::SearchToolBar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SearchToolBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::Settings >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_Settings_IDX]); }
template<> inline PyTypeObject *SbkType< ::SideBarInterface >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SideBarInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::SideBarManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SideBarManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::SideWidget >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SideWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::SiteSettingsManager::Permission >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SiteSettingsManager_Permission_IDX]); }
template<> inline PyTypeObject *SbkType< ::SiteSettingsManager::PageOptions >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SiteSettingsManager_PageOptions_IDX]); }
template<> inline PyTypeObject *SbkType< ::SiteSettingsManager >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SiteSettingsManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::SiteSettingsManager::SiteSettings >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SiteSettingsManager_SiteSettings_IDX]); }
template<> inline PyTypeObject *SbkType< ::SqlDatabase >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SqlDatabase_IDX]); }
template<> inline PyTypeObject *SbkType< ::SqlQueryJob >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SqlQueryJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::SqueezeLabelV1 >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SqueezeLabelV1_IDX]); }
template<> inline PyTypeObject *SbkType< ::SqueezeLabelV2 >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_SqueezeLabelV2_IDX]); }
template<> inline PyTypeObject *SbkType< ::StatusBar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_StatusBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabBar >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabContextMenu::Option >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabContextMenu_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<TabContextMenu::Option> >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_QFlags_TabContextMenu_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabContextMenu >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabContextMenu_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabIcon >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabIcon_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabIcon::Data >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabIcon_Data_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabModel::Roles >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabModel >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabMruModel >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabMruModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabStackedWidget >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabStackedWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabTreeModel >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabTreeModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabWidget >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::TabbedWebView >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_TabbedWebView_IDX]); }
template<> inline PyTypeObject *SbkType< ::ToolButton >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_ToolButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::UrlInterceptor >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_UrlInterceptor_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebHitTestResult >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebHitTestResult_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebInspector >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebInspector_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebPage::JsWorld >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebPage_JsWorld_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebPage >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebPage_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebTab::AddChildBehavior >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebTab_AddChildBehavior_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebTab >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebTab_IDX]); }
template<> inline PyTypeObject *SbkType< ::WebView >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WebView_IDX]); }
template<> inline PyTypeObject *SbkType< ::WheelHelper::Direction >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WheelHelper_Direction_IDX]); }
template<> inline PyTypeObject *SbkType< ::WheelHelper >() { return Shiboken::Module::get(SbkPyFalkonTypeStructs[SBK_WheelHelper_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_PYFALKON_PYTHON_H

