/********************************************************************************
** Form generated from reading UI file 'adblockaddsubscriptiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADBLOCKADDSUBSCRIPTIONDIALOG_H
#define UI_ADBLOCKADDSUBSCRIPTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>

QT_BEGIN_NAMESPACE

class Ui_AdBlockAddSubscriptionDialog
{
public:
    QFormLayout *formLayout;
    QComboBox *comboBox;
    QLabel *label;
    QLineEdit *title;
    QLabel *label_2;
    QLineEdit *url;
    QDialogButtonBox *buttonBox;
    QLabel *label_3;

    void setupUi(QDialog *AdBlockAddSubscriptionDialog)
    {
        if (AdBlockAddSubscriptionDialog->objectName().isEmpty())
            AdBlockAddSubscriptionDialog->setObjectName("AdBlockAddSubscriptionDialog");
        AdBlockAddSubscriptionDialog->resize(557, 162);
        formLayout = new QFormLayout(AdBlockAddSubscriptionDialog);
        formLayout->setObjectName("formLayout");
        comboBox = new QComboBox(AdBlockAddSubscriptionDialog);
        comboBox->setObjectName("comboBox");

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, comboBox);

        label = new QLabel(AdBlockAddSubscriptionDialog);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        title = new QLineEdit(AdBlockAddSubscriptionDialog);
        title->setObjectName("title");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, title);

        label_2 = new QLabel(AdBlockAddSubscriptionDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        url = new QLineEdit(AdBlockAddSubscriptionDialog);
        url->setObjectName("url");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, url);

        buttonBox = new QDialogButtonBox(AdBlockAddSubscriptionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, buttonBox);

        label_3 = new QLabel(AdBlockAddSubscriptionDialog);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, label_3);


        retranslateUi(AdBlockAddSubscriptionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AdBlockAddSubscriptionDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AdBlockAddSubscriptionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AdBlockAddSubscriptionDialog);
    } // setupUi

    void retranslateUi(QDialog *AdBlockAddSubscriptionDialog)
    {
        AdBlockAddSubscriptionDialog->setWindowTitle(QCoreApplication::translate("AdBlockAddSubscriptionDialog", "Add Subscription", nullptr));
        label->setText(QCoreApplication::translate("AdBlockAddSubscriptionDialog", "Title:", nullptr));
        label_2->setText(QCoreApplication::translate("AdBlockAddSubscriptionDialog", "Address:", nullptr));
        label_3->setText(QCoreApplication::translate("AdBlockAddSubscriptionDialog", "Add new subscription to AdBlock:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AdBlockAddSubscriptionDialog: public Ui_AdBlockAddSubscriptionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADBLOCKADDSUBSCRIPTIONDIALOG_H
