/********************************************************************************
** Form generated from reading UI file 'searchenginesdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHENGINESDIALOG_H
#define UI_SEARCHENGINESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SearchEnginesDialog
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QPushButton *add;
    QPushButton *remove;
    QPushButton *edit;
    QSpacerItem *verticalSpacer;
    QPushButton *setAsDefault;
    QPushButton *moveUp;
    QPushButton *moveDown;
    QTreeWidget *treeWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *defaults;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SearchEnginesDialog)
    {
        if (SearchEnginesDialog->objectName().isEmpty())
            SearchEnginesDialog->setObjectName("SearchEnginesDialog");
        SearchEnginesDialog->resize(465, 299);
        gridLayout = new QGridLayout(SearchEnginesDialog);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add = new QPushButton(SearchEnginesDialog);
        add->setObjectName("add");

        verticalLayout->addWidget(add);

        remove = new QPushButton(SearchEnginesDialog);
        remove->setObjectName("remove");

        verticalLayout->addWidget(remove);

        edit = new QPushButton(SearchEnginesDialog);
        edit->setObjectName("edit");

        verticalLayout->addWidget(edit);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        setAsDefault = new QPushButton(SearchEnginesDialog);
        setAsDefault->setObjectName("setAsDefault");

        verticalLayout->addWidget(setAsDefault);

        moveUp = new QPushButton(SearchEnginesDialog);
        moveUp->setObjectName("moveUp");

        verticalLayout->addWidget(moveUp);

        moveDown = new QPushButton(SearchEnginesDialog);
        moveDown->setObjectName("moveDown");

        verticalLayout->addWidget(moveDown);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        treeWidget = new QTreeWidget(SearchEnginesDialog);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setRootIsDecorated(false);
        treeWidget->setSortingEnabled(true);
        treeWidget->header()->setDefaultSectionSize(0);

        gridLayout->addWidget(treeWidget, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        defaults = new QPushButton(SearchEnginesDialog);
        defaults->setObjectName("defaults");

        horizontalLayout->addWidget(defaults);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(SearchEnginesDialog);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy);
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(buttonBox);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 2);


        retranslateUi(SearchEnginesDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SearchEnginesDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SearchEnginesDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SearchEnginesDialog);
    } // setupUi

    void retranslateUi(QDialog *SearchEnginesDialog)
    {
        SearchEnginesDialog->setWindowTitle(QCoreApplication::translate("SearchEnginesDialog", "Manage Search Engines", nullptr));
        add->setText(QCoreApplication::translate("SearchEnginesDialog", "Add...", nullptr));
        remove->setText(QCoreApplication::translate("SearchEnginesDialog", "Remove", nullptr));
        edit->setText(QCoreApplication::translate("SearchEnginesDialog", "Edit", nullptr));
        setAsDefault->setText(QCoreApplication::translate("SearchEnginesDialog", "Set as default", nullptr));
        moveUp->setText(QCoreApplication::translate("SearchEnginesDialog", "Up", nullptr));
        moveDown->setText(QCoreApplication::translate("SearchEnginesDialog", "Down", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("SearchEnginesDialog", "Shortcut", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("SearchEnginesDialog", "Search Engine", nullptr));
        defaults->setText(QCoreApplication::translate("SearchEnginesDialog", "Defaults", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SearchEnginesDialog: public Ui_SearchEnginesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHENGINESDIALOG_H
