/********************************************************************************
** Form generated from reading UI file 'autofillmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOFILLMANAGER_H
#define UI_AUTOFILLMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "treewidget.h"

QT_BEGIN_NAMESPACE

class Ui_AutoFillManager
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *currentBackend;
    QPushButton *changeBackend;
    QPushButton *backendOptions;
    QSpacerItem *horizontalSpacer_2;
    QTabWidget *tabWidget;
    QWidget *tabPass;
    QGridLayout *gridLayout;
    TreeWidget *treePass;
    QHBoxLayout *showPasswordsLayout;
    QPushButton *importExport;
    QLabel *importExportLabel;
    QSpacerItem *horizontalSpacer;
    QPushButton *showPasswords;
    QLineEdit *search;
    QVBoxLayout *verticalLayout;
    QPushButton *editPass;
    QPushButton *removePass;
    QPushButton *removeAllPass;
    QSpacerItem *verticalSpacer;
    QWidget *tabExcept;
    QHBoxLayout *horizontalLayout_3;
    TreeWidget *treeExcept;
    QVBoxLayout *verticalLayout_2;
    QPushButton *removeExcept;
    QPushButton *removeAllExcept;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *AutoFillManager)
    {
        if (AutoFillManager->objectName().isEmpty())
            AutoFillManager->setObjectName("AutoFillManager");
        AutoFillManager->resize(537, 372);
        verticalLayout_3 = new QVBoxLayout(AutoFillManager);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(AutoFillManager);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        currentBackend = new QLabel(AutoFillManager);
        currentBackend->setObjectName("currentBackend");

        horizontalLayout->addWidget(currentBackend);

        changeBackend = new QPushButton(AutoFillManager);
        changeBackend->setObjectName("changeBackend");

        horizontalLayout->addWidget(changeBackend);

        backendOptions = new QPushButton(AutoFillManager);
        backendOptions->setObjectName("backendOptions");

        horizontalLayout->addWidget(backendOptions);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout);

        tabWidget = new QTabWidget(AutoFillManager);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setFocusPolicy(Qt::NoFocus);
        tabPass = new QWidget();
        tabPass->setObjectName("tabPass");
        gridLayout = new QGridLayout(tabPass);
        gridLayout->setObjectName("gridLayout");
        treePass = new TreeWidget(tabPass);
        treePass->setObjectName("treePass");
        treePass->setIndentation(0);
        treePass->setSortingEnabled(true);
        treePass->header()->setMinimumSectionSize(100);

        gridLayout->addWidget(treePass, 2, 0, 1, 1);

        showPasswordsLayout = new QHBoxLayout();
        showPasswordsLayout->setObjectName("showPasswordsLayout");
        importExport = new QPushButton(tabPass);
        importExport->setObjectName("importExport");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(importExport->sizePolicy().hasHeightForWidth());
        importExport->setSizePolicy(sizePolicy1);

        showPasswordsLayout->addWidget(importExport);

        importExportLabel = new QLabel(tabPass);
        importExportLabel->setObjectName("importExportLabel");

        showPasswordsLayout->addWidget(importExportLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        showPasswordsLayout->addItem(horizontalSpacer);

        showPasswords = new QPushButton(tabPass);
        showPasswords->setObjectName("showPasswords");

        showPasswordsLayout->addWidget(showPasswords);


        gridLayout->addLayout(showPasswordsLayout, 3, 0, 1, 2);

        search = new QLineEdit(tabPass);
        search->setObjectName("search");

        gridLayout->addWidget(search, 1, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        editPass = new QPushButton(tabPass);
        editPass->setObjectName("editPass");

        verticalLayout->addWidget(editPass);

        removePass = new QPushButton(tabPass);
        removePass->setObjectName("removePass");

        verticalLayout->addWidget(removePass);

        removeAllPass = new QPushButton(tabPass);
        removeAllPass->setObjectName("removeAllPass");

        verticalLayout->addWidget(removeAllPass);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 1, 1, 2, 1);

        tabWidget->addTab(tabPass, QString());
        tabExcept = new QWidget();
        tabExcept->setObjectName("tabExcept");
        horizontalLayout_3 = new QHBoxLayout(tabExcept);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        treeExcept = new TreeWidget(tabExcept);
        treeExcept->setObjectName("treeExcept");
        treeExcept->setSortingEnabled(true);

        horizontalLayout_3->addWidget(treeExcept);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        removeExcept = new QPushButton(tabExcept);
        removeExcept->setObjectName("removeExcept");

        verticalLayout_2->addWidget(removeExcept);

        removeAllExcept = new QPushButton(tabExcept);
        removeAllExcept->setObjectName("removeAllExcept");

        verticalLayout_2->addWidget(removeAllExcept);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        horizontalLayout_3->addLayout(verticalLayout_2);

        tabWidget->addTab(tabExcept, QString());

        verticalLayout_3->addWidget(tabWidget);


        retranslateUi(AutoFillManager);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AutoFillManager);
    } // setupUi

    void retranslateUi(QWidget *AutoFillManager)
    {
        label->setText(QCoreApplication::translate("AutoFillManager", "Passwords are stored in:", nullptr));
        changeBackend->setText(QCoreApplication::translate("AutoFillManager", "Change backend", nullptr));
        backendOptions->setText(QCoreApplication::translate("AutoFillManager", "Backend options", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treePass->headerItem();
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("AutoFillManager", "Password", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("AutoFillManager", "Username", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("AutoFillManager", "Server", nullptr));
        importExport->setText(QCoreApplication::translate("AutoFillManager", "Import and Export", nullptr));
        importExportLabel->setText(QString());
        showPasswords->setText(QCoreApplication::translate("AutoFillManager", "Show Passwords", nullptr));
        editPass->setText(QCoreApplication::translate("AutoFillManager", "Edit", nullptr));
        removePass->setText(QCoreApplication::translate("AutoFillManager", "Remove", nullptr));
        removeAllPass->setText(QCoreApplication::translate("AutoFillManager", "Remove All", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabPass), QCoreApplication::translate("AutoFillManager", "Passwords", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = treeExcept->headerItem();
        ___qtreewidgetitem1->setText(0, QCoreApplication::translate("AutoFillManager", "Server", nullptr));
        removeExcept->setText(QCoreApplication::translate("AutoFillManager", "Remove", nullptr));
        removeAllExcept->setText(QCoreApplication::translate("AutoFillManager", "Remove All", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabExcept), QCoreApplication::translate("AutoFillManager", "Exceptions", nullptr));
        (void)AutoFillManager;
    } // retranslateUi

};

namespace Ui {
    class AutoFillManager: public Ui_AutoFillManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOFILLMANAGER_H
