/********************************************************************************
** Form generated from reading UI file 'siteinfo.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SITEINFO_H
#define UI_SITEINFO_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "horizontallistwidget.h"
#include "squeezelabelv2.h"

QT_BEGIN_NAMESPACE

class Ui_SiteInfo
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    SqueezeLabelV2 *heading;
    HorizontalListWidget *listWidget;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QGridLayout *gridLayout_2;
    QFormLayout *formLayout;
    QLabel *label_3;
    SqueezeLabelV2 *siteAddress;
    QLabel *label_6;
    SqueezeLabelV2 *encodingLabel;
    QLabel *label_9;
    QTreeWidget *treeTags;
    QLabel *label_2;
    QLabel *securityLabel;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QWidget *page2;
    QVBoxLayout *verticalLayout_3;
    QSplitter *splitter;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout_2;
    QTreeWidget *treeImages;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QDialogButtonBox *saveButton;
    QLabel *label_5;
    QGraphicsView *mediaPreview;
    QWidget *page3;
    QVBoxLayout *verticalLayout_4;
    QListWidget *listPermissions;

    void setupUi(QDialog *SiteInfo)
    {
        if (SiteInfo->objectName().isEmpty())
            SiteInfo->setObjectName("SiteInfo");
        SiteInfo->resize(590, 492);
        gridLayout = new QGridLayout(SiteInfo);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(SiteInfo);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 1);

        heading = new SqueezeLabelV2(SiteInfo);
        heading->setObjectName("heading");
        heading->setMaximumSize(QSize(550, 16777215));
        heading->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(heading, 1, 0, 1, 1);

        listWidget = new HorizontalListWidget(SiteInfo);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        listWidget->setObjectName("listWidget");

        gridLayout->addWidget(listWidget, 0, 0, 1, 1);

        stackedWidget = new QStackedWidget(SiteInfo);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        gridLayout_2 = new QGridLayout(page);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(-1, 0, -1, 0);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_3 = new QLabel(page);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        siteAddress = new SqueezeLabelV2(page);
        siteAddress->setObjectName("siteAddress");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(siteAddress->sizePolicy().hasHeightForWidth());
        siteAddress->setSizePolicy(sizePolicy1);
        siteAddress->setMaximumSize(QSize(460, 16777215));
        siteAddress->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, siteAddress);

        label_6 = new QLabel(page);
        label_6->setObjectName("label_6");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_6);

        encodingLabel = new SqueezeLabelV2(page);
        encodingLabel->setObjectName("encodingLabel");
        encodingLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, encodingLabel);


        gridLayout_2->addLayout(formLayout, 0, 0, 1, 4);

        label_9 = new QLabel(page);
        label_9->setObjectName("label_9");

        gridLayout_2->addWidget(label_9, 1, 0, 1, 4);

        treeTags = new QTreeWidget(page);
        treeTags->setObjectName("treeTags");
        treeTags->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeTags->setSortingEnabled(true);
        treeTags->header()->setMinimumSectionSize(200);

        gridLayout_2->addWidget(treeTags, 3, 0, 1, 4);

        label_2 = new QLabel(page);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label_2, 4, 0, 1, 2);

        securityLabel = new QLabel(page);
        securityLabel->setObjectName("securityLabel");

        gridLayout_2->addWidget(securityLabel, 5, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 5, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 5, 2, 1, 1);

        stackedWidget->addWidget(page);
        page2 = new QWidget();
        page2->setObjectName("page2");
        verticalLayout_3 = new QVBoxLayout(page2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        splitter = new QSplitter(page2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        verticalLayoutWidget = new QWidget(splitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayout_2 = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        treeImages = new QTreeWidget(verticalLayoutWidget);
        treeImages->setObjectName("treeImages");
        treeImages->setMinimumSize(QSize(0, 0));
        treeImages->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeImages->setItemsExpandable(false);
        treeImages->setSortingEnabled(true);
        treeImages->header()->setMinimumSectionSize(200);

        verticalLayout_2->addWidget(treeImages);

        splitter->addWidget(verticalLayoutWidget);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        saveButton = new QDialogButtonBox(layoutWidget);
        saveButton->setObjectName("saveButton");
        saveButton->setStandardButtons(QDialogButtonBox::Save);

        verticalLayout->addWidget(saveButton);

        label_5 = new QLabel(layoutWidget);
        label_5->setObjectName("label_5");
        label_5->setMaximumSize(QSize(16777215, 20));

        verticalLayout->addWidget(label_5);

        mediaPreview = new QGraphicsView(layoutWidget);
        mediaPreview->setObjectName("mediaPreview");

        verticalLayout->addWidget(mediaPreview);

        splitter->addWidget(layoutWidget);

        verticalLayout_3->addWidget(splitter);

        stackedWidget->addWidget(page2);
        page3 = new QWidget();
        page3->setObjectName("page3");
        verticalLayout_4 = new QVBoxLayout(page3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        listPermissions = new QListWidget(page3);
        listPermissions->setObjectName("listPermissions");
        listPermissions->setAlternatingRowColors(true);
        listPermissions->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout_4->addWidget(listPermissions);

        stackedWidget->addWidget(page3);

        gridLayout->addWidget(stackedWidget, 2, 0, 1, 1);


        retranslateUi(SiteInfo);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SiteInfo, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SiteInfo, qOverload<>(&QDialog::reject));

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SiteInfo);
    } // setupUi

    void retranslateUi(QDialog *SiteInfo)
    {
        SiteInfo->setWindowTitle(QCoreApplication::translate("SiteInfo", "Site Info", nullptr));
        heading->setText(QString());

        const bool __sortingEnabled = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("SiteInfo", "General", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("SiteInfo", "Media", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("SiteInfo", "Permissions", nullptr));
        listWidget->setSortingEnabled(__sortingEnabled);

        label_3->setText(QCoreApplication::translate("SiteInfo", "Site address:", nullptr));
        siteAddress->setText(QString());
        label_6->setText(QCoreApplication::translate("SiteInfo", "Encoding:", nullptr));
        encodingLabel->setText(QString());
        label_9->setText(QCoreApplication::translate("SiteInfo", "Meta tags of site:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeTags->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("SiteInfo", "Value", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("SiteInfo", "Tag", nullptr));
        label_2->setText(QCoreApplication::translate("SiteInfo", "<b>Security information</b>", nullptr));
        securityLabel->setText(QString());
        QTreeWidgetItem *___qtreewidgetitem1 = treeImages->headerItem();
        ___qtreewidgetitem1->setText(1, QCoreApplication::translate("SiteInfo", "Image address", nullptr));
        ___qtreewidgetitem1->setText(0, QCoreApplication::translate("SiteInfo", "Image", nullptr));
        label_5->setText(QCoreApplication::translate("SiteInfo", "<b>Preview</b>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SiteInfo: public Ui_SiteInfo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SITEINFO_H
