/********************************************************************************
** Form generated from reading UI file 'sitesettingsattributesitem.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SITESETTINGSATTRIBUTESITEM_H
#define UI_SITESETTINGSATTRIBUTESITEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SiteSettingsAttributesItem
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QPushButton *browseButton;

    void setupUi(QWidget *SiteSettingsAttributesItem)
    {
        if (SiteSettingsAttributesItem->objectName().isEmpty())
            SiteSettingsAttributesItem->setObjectName("SiteSettingsAttributesItem");
        SiteSettingsAttributesItem->resize(556, 61);
        verticalLayout = new QVBoxLayout(SiteSettingsAttributesItem);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SiteSettingsAttributesItem);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        browseButton = new QPushButton(SiteSettingsAttributesItem);
        browseButton->setObjectName("browseButton");

        horizontalLayout->addWidget(browseButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(SiteSettingsAttributesItem);

        QMetaObject::connectSlotsByName(SiteSettingsAttributesItem);
    } // setupUi

    void retranslateUi(QWidget *SiteSettingsAttributesItem)
    {
        label->setText(QString());
        browseButton->setText(QCoreApplication::translate("SiteSettingsAttributesItem", "Browse", nullptr));
        (void)SiteSettingsAttributesItem;
    } // retranslateUi

};

namespace Ui {
    class SiteSettingsAttributesItem: public Ui_SiteSettingsAttributesItem {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SITESETTINGSATTRIBUTESITEM_H
