/****************************************************************************
** Meta object code from reading C++ file 'qmlwindows.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.0/src/lib/plugins/qml/api/windows/qmlwindows.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlwindows.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10QmlWindowsE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlWindows::qt_create_metaobjectdata<qt_meta_tag_ZN10QmlWindowsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlWindows",
        "created",
        "",
        "QmlWindow*",
        "window",
        "removed",
        "get",
        "id",
        "getCurrent",
        "getAll",
        "QList<QObject*>",
        "create",
        "QVariantMap",
        "map",
        "remove",
        "windowId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'created'
        QtMocHelpers::SignalData<void(QmlWindow *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void(QmlWindow *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QmlWindow *(int) const>(6, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'getCurrent'
        QtMocHelpers::MethodData<QmlWindow *() const>(8, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'getAll'
        QtMocHelpers::MethodData<QList<QObject*>() const>(9, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Method 'create'
        QtMocHelpers::MethodData<QmlWindow *(const QVariantMap &) const>(11, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<void(int) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlWindows, qt_meta_tag_ZN10QmlWindowsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlWindows::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QmlWindowsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QmlWindowsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10QmlWindowsE_t>.metaTypes,
    nullptr
} };

void QmlWindows::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlWindows *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->created((*reinterpret_cast<std::add_pointer_t<QmlWindow*>>(_a[1]))); break;
        case 1: _t->removed((*reinterpret_cast<std::add_pointer_t<QmlWindow*>>(_a[1]))); break;
        case 2: { QmlWindow* _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QmlWindow**>(_a[0]) = std::move(_r); }  break;
        case 3: { QmlWindow* _r = _t->getCurrent();
            if (_a[0]) *reinterpret_cast<QmlWindow**>(_a[0]) = std::move(_r); }  break;
        case 4: { QList<QObject*> _r = _t->getAll();
            if (_a[0]) *reinterpret_cast<QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QmlWindow* _r = _t->create((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QmlWindow**>(_a[0]) = std::move(_r); }  break;
        case 6: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlWindow* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlWindows::*)(QmlWindow * )>(_a, &QmlWindows::created, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlWindows::*)(QmlWindow * )>(_a, &QmlWindows::removed, 1))
            return;
    }
}

const QMetaObject *QmlWindows::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlWindows::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QmlWindowsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlWindows::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QmlWindows::created(QmlWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QmlWindows::removed(QmlWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
