/****************************************************************************
** Meta object code from reading C++ file 'tabbedwebview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.0/src/lib/webtab/tabbedwebview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabbedwebview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TabbedWebViewE_t {};
} // unnamed namespace

template <> constexpr inline auto TabbedWebView::qt_create_metaobjectdata<qt_meta_tag_ZN13TabbedWebViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabbedWebView",
        "wantsCloseTab",
        "",
        "ipChanged",
        "setAsCurrentTab",
        "userLoadAction",
        "LoadRequest",
        "req",
        "slotLoadStarted",
        "slotLoadFinished",
        "slotLoadProgress",
        "prog",
        "linkHovered",
        "link",
        "setIp",
        "QHostInfo",
        "info",
        "inspectElement"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wantsCloseTab'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'ipChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setAsCurrentTab'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'userLoadAction'
        QtMocHelpers::SlotData<void(const LoadRequest &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'slotLoadStarted'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadFinished'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadProgress'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'linkHovered'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setIp'
        QtMocHelpers::SlotData<void(const QHostInfo &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'inspectElement'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabbedWebView, qt_meta_tag_ZN13TabbedWebViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabbedWebView::staticMetaObject = { {
    QMetaObject::SuperData::link<WebView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TabbedWebViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TabbedWebViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TabbedWebViewE_t>.metaTypes,
    nullptr
} };

void TabbedWebView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabbedWebView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wantsCloseTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->ipChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setAsCurrentTab(); break;
        case 3: _t->userLoadAction((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1]))); break;
        case 4: _t->slotLoadStarted(); break;
        case 5: _t->slotLoadFinished(); break;
        case 6: _t->slotLoadProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->linkHovered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setIp((*reinterpret_cast<std::add_pointer_t<QHostInfo>>(_a[1]))); break;
        case 9: _t->inspectElement(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabbedWebView::*)(int )>(_a, &TabbedWebView::wantsCloseTab, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabbedWebView::*)(const QString & )>(_a, &TabbedWebView::ipChanged, 1))
            return;
    }
}

const QMetaObject *TabbedWebView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabbedWebView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TabbedWebViewE_t>.strings))
        return static_cast<void*>(this);
    return WebView::qt_metacast(_clname);
}

int TabbedWebView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WebView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void TabbedWebView::wantsCloseTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TabbedWebView::ipChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
