/********************************************************************************
** Form generated from reading UI file 'fcm_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FCM_DIALOG_H
#define UI_FCM_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "squeezelabelv2.h"
#include "treewidget.h"

QT_BEGIN_NAMESPACE

class Ui_FCM_Dialog
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_13;
    QVBoxLayout *verticalLayout_10;
    QGridLayout *gridLayout_11;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_4;
    QLineEdit *search;
    QVBoxLayout *verticalLayout_8;
    QGridLayout *gridLayout_12;
    SqueezeLabelV2 *name;
    QLabel *label_22;
    QLabel *label_6;
    QLabel *labelSize_2;
    QLabel *label_7;
    SqueezeLabelV2 *lastModified;
    SqueezeLabelV2 *server;
    SqueezeLabelV2 *size;
    QLabel *label_23;
    QTextEdit *textEdit;
    QVBoxLayout *verticalLayout_9;
    QLabel *label_24;
    TreeWidget *flashCookieTree;
    QHBoxLayout *horizontalLayout_8;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *reloadFromDisk;
    QHBoxLayout *horizontalLayout_9;
    QLabel *labelPath;
    QLabel *path;
    QHBoxLayout *horizontalLayout_10;
    QPushButton *removeAll;
    QPushButton *removeOne;
    QDialogButtonBox *close;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_5;
    QLabel *label_16;
    QListWidget *whiteList;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *whiteRemove;
    QPushButton *whiteAdd;
    QLabel *label_17;
    QLabel *label_21;
    QLabel *label_18;
    QListWidget *blackList;
    QHBoxLayout *horizontalLayout_11;
    QSpacerItem *horizontalSpacer;
    QPushButton *blackRemove;
    QPushButton *blackAdd;
    QDialogButtonBox *close2;
    QWidget *settingsTab;
    QGridLayout *gridLayout_3;
    QGridLayout *gridLayout_2;
    QLabel *label_13;
    QHBoxLayout *horizontalLayout;
    QCheckBox *autoMode;
    QLabel *labelAutoMode;
    QDialogButtonBox *close3;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_19;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *notification;
    QLabel *labelNotification;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *deleteAllOnStartExit;
    QLabel *labelDeleteAll;

    void setupUi(QDialog *FCM_Dialog)
    {
        if (FCM_Dialog->objectName().isEmpty())
            FCM_Dialog->setObjectName("FCM_Dialog");
        FCM_Dialog->resize(508, 431);
        gridLayout = new QGridLayout(FCM_Dialog);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(FCM_Dialog);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_13 = new QGridLayout(tab);
        gridLayout_13->setObjectName("gridLayout_13");
        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setSizeConstraint(QLayout::SetNoConstraint);
        gridLayout_11 = new QGridLayout();
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_11->setVerticalSpacing(6);
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(6);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_4 = new QLabel(tab);
        label_4->setObjectName("label_4");

        horizontalLayout_7->addWidget(label_4);

        search = new QLineEdit(tab);
        search->setObjectName("search");

        horizontalLayout_7->addWidget(search);


        gridLayout_11->addLayout(horizontalLayout_7, 4, 1, 1, 1);

        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setSpacing(6);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setSizeConstraint(QLayout::SetNoConstraint);
        gridLayout_12 = new QGridLayout();
        gridLayout_12->setSpacing(6);
        gridLayout_12->setObjectName("gridLayout_12");
        gridLayout_12->setSizeConstraint(QLayout::SetNoConstraint);
        name = new SqueezeLabelV2(tab);
        name->setObjectName("name");
        name->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_12->addWidget(name, 0, 1, 1, 1);

        label_22 = new QLabel(tab);
        label_22->setObjectName("label_22");

        gridLayout_12->addWidget(label_22, 3, 0, 1, 1);

        label_6 = new QLabel(tab);
        label_6->setObjectName("label_6");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy);
        label_6->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_12->addWidget(label_6, 0, 0, 1, 1);

        labelSize_2 = new QLabel(tab);
        labelSize_2->setObjectName("labelSize_2");

        gridLayout_12->addWidget(labelSize_2, 1, 0, 1, 1);

        label_7 = new QLabel(tab);
        label_7->setObjectName("label_7");

        gridLayout_12->addWidget(label_7, 2, 0, 1, 1);

        lastModified = new SqueezeLabelV2(tab);
        lastModified->setObjectName("lastModified");
        lastModified->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_12->addWidget(lastModified, 3, 1, 1, 1);

        server = new SqueezeLabelV2(tab);
        server->setObjectName("server");
        server->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_12->addWidget(server, 2, 1, 1, 1);

        size = new SqueezeLabelV2(tab);
        size->setObjectName("size");
        size->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_12->addWidget(size, 1, 1, 1, 1);


        verticalLayout_8->addLayout(gridLayout_12);

        label_23 = new QLabel(tab);
        label_23->setObjectName("label_23");

        verticalLayout_8->addWidget(label_23);

        textEdit = new QTextEdit(tab);
        textEdit->setObjectName("textEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textEdit->sizePolicy().hasHeightForWidth());
        textEdit->setSizePolicy(sizePolicy1);
        textEdit->setAcceptRichText(true);
        textEdit->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        verticalLayout_8->addWidget(textEdit);


        gridLayout_11->addLayout(verticalLayout_8, 5, 4, 1, 1);

        verticalLayout_9 = new QVBoxLayout();
        verticalLayout_9->setSpacing(0);
        verticalLayout_9->setObjectName("verticalLayout_9");
        label_24 = new QLabel(tab);
        label_24->setObjectName("label_24");
        label_24->setWordWrap(true);

        verticalLayout_9->addWidget(label_24);

        flashCookieTree = new TreeWidget(tab);
        flashCookieTree->setObjectName("flashCookieTree");
        flashCookieTree->setSortingEnabled(true);
        flashCookieTree->setColumnCount(1);
        flashCookieTree->header()->setStretchLastSection(true);

        verticalLayout_9->addWidget(flashCookieTree);


        gridLayout_11->addLayout(verticalLayout_9, 5, 1, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_4);

        reloadFromDisk = new QPushButton(tab);
        reloadFromDisk->setObjectName("reloadFromDisk");

        horizontalLayout_8->addWidget(reloadFromDisk);


        gridLayout_11->addLayout(horizontalLayout_8, 4, 4, 1, 1);


        verticalLayout_10->addLayout(gridLayout_11);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        labelPath = new QLabel(tab);
        labelPath->setObjectName("labelPath");

        horizontalLayout_9->addWidget(labelPath);

        path = new QLabel(tab);
        path->setObjectName("path");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(path->sizePolicy().hasHeightForWidth());
        path->setSizePolicy(sizePolicy2);
        path->setWordWrap(true);
        path->setOpenExternalLinks(true);
        path->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_9->addWidget(path);


        verticalLayout_10->addLayout(horizontalLayout_9);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        removeAll = new QPushButton(tab);
        removeAll->setObjectName("removeAll");

        horizontalLayout_10->addWidget(removeAll);

        removeOne = new QPushButton(tab);
        removeOne->setObjectName("removeOne");

        horizontalLayout_10->addWidget(removeOne);

        close = new QDialogButtonBox(tab);
        close->setObjectName("close");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(close->sizePolicy().hasHeightForWidth());
        close->setSizePolicy(sizePolicy3);
        close->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_10->addWidget(close);


        verticalLayout_10->addLayout(horizontalLayout_10);


        gridLayout_13->addLayout(verticalLayout_10, 0, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout = new QVBoxLayout(tab_2);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        label_16 = new QLabel(tab_2);
        label_16->setObjectName("label_16");

        gridLayout_5->addWidget(label_16, 0, 0, 1, 1);

        whiteList = new QListWidget(tab_2);
        whiteList->setObjectName("whiteList");
        sizePolicy1.setHeightForWidth(whiteList->sizePolicy().hasHeightForWidth());
        whiteList->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(whiteList, 2, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        whiteRemove = new QPushButton(tab_2);
        whiteRemove->setObjectName("whiteRemove");

        horizontalLayout_5->addWidget(whiteRemove);

        whiteAdd = new QPushButton(tab_2);
        whiteAdd->setObjectName("whiteAdd");

        horizontalLayout_5->addWidget(whiteAdd);


        gridLayout_5->addLayout(horizontalLayout_5, 3, 0, 1, 1);

        label_17 = new QLabel(tab_2);
        label_17->setObjectName("label_17");
        label_17->setWordWrap(true);

        gridLayout_5->addWidget(label_17, 1, 0, 1, 1);

        label_21 = new QLabel(tab_2);
        label_21->setObjectName("label_21");

        gridLayout_5->addWidget(label_21, 0, 1, 1, 1);

        label_18 = new QLabel(tab_2);
        label_18->setObjectName("label_18");
        label_18->setWordWrap(true);

        gridLayout_5->addWidget(label_18, 1, 1, 1, 1);

        blackList = new QListWidget(tab_2);
        blackList->setObjectName("blackList");
        sizePolicy1.setHeightForWidth(blackList->sizePolicy().hasHeightForWidth());
        blackList->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(blackList, 2, 1, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer);

        blackRemove = new QPushButton(tab_2);
        blackRemove->setObjectName("blackRemove");

        horizontalLayout_11->addWidget(blackRemove);

        blackAdd = new QPushButton(tab_2);
        blackAdd->setObjectName("blackAdd");

        horizontalLayout_11->addWidget(blackAdd);


        gridLayout_5->addLayout(horizontalLayout_11, 3, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_5);

        close2 = new QDialogButtonBox(tab_2);
        close2->setObjectName("close2");
        close2->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(close2);

        tabWidget->addTab(tab_2, QString());
        settingsTab = new QWidget();
        settingsTab->setObjectName("settingsTab");
        gridLayout_3 = new QGridLayout(settingsTab);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setSizeConstraint(QLayout::SetNoConstraint);
        label_13 = new QLabel(settingsTab);
        label_13->setObjectName("label_13");

        gridLayout_2->addWidget(label_13, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        autoMode = new QCheckBox(settingsTab);
        autoMode->setObjectName("autoMode");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(autoMode->sizePolicy().hasHeightForWidth());
        autoMode->setSizePolicy(sizePolicy4);

        horizontalLayout->addWidget(autoMode);

        labelAutoMode = new QLabel(settingsTab);
        labelAutoMode->setObjectName("labelAutoMode");
        labelAutoMode->setWordWrap(true);

        horizontalLayout->addWidget(labelAutoMode);


        gridLayout_2->addLayout(horizontalLayout, 5, 0, 1, 1);

        close3 = new QDialogButtonBox(settingsTab);
        close3->setObjectName("close3");
        close3->setStandardButtons(QDialogButtonBox::Close);

        gridLayout_2->addWidget(close3, 16, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_3, 14, 0, 1, 1);

        label_19 = new QLabel(settingsTab);
        label_19->setObjectName("label_19");
        label_19->setWordWrap(true);
        label_19->setOpenExternalLinks(true);

        gridLayout_2->addWidget(label_19, 15, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        notification = new QCheckBox(settingsTab);
        notification->setObjectName("notification");
        sizePolicy4.setHeightForWidth(notification->sizePolicy().hasHeightForWidth());
        notification->setSizePolicy(sizePolicy4);

        horizontalLayout_2->addWidget(notification);

        labelNotification = new QLabel(settingsTab);
        labelNotification->setObjectName("labelNotification");
        labelNotification->setWordWrap(true);

        horizontalLayout_2->addWidget(labelNotification);


        gridLayout_2->addLayout(horizontalLayout_2, 6, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        deleteAllOnStartExit = new QCheckBox(settingsTab);
        deleteAllOnStartExit->setObjectName("deleteAllOnStartExit");
        sizePolicy4.setHeightForWidth(deleteAllOnStartExit->sizePolicy().hasHeightForWidth());
        deleteAllOnStartExit->setSizePolicy(sizePolicy4);

        horizontalLayout_3->addWidget(deleteAllOnStartExit);

        labelDeleteAll = new QLabel(settingsTab);
        labelDeleteAll->setObjectName("labelDeleteAll");
        labelDeleteAll->setWordWrap(true);

        horizontalLayout_3->addWidget(labelDeleteAll);


        gridLayout_2->addLayout(horizontalLayout_3, 13, 0, 1, 1);


        gridLayout_3->addLayout(gridLayout_2, 0, 0, 1, 1);

        tabWidget->addTab(settingsTab, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        labelAutoMode->setBuddy(autoMode);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FCM_Dialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(FCM_Dialog);
    } // setupUi

    void retranslateUi(QDialog *FCM_Dialog)
    {
        FCM_Dialog->setWindowTitle(QCoreApplication::translate("FCM_Dialog", "Flash Cookies", nullptr));
        label_4->setText(QCoreApplication::translate("FCM_Dialog", "Find: ", nullptr));
        name->setText(QCoreApplication::translate("FCM_Dialog", "<flash cookie not selected>", nullptr));
        label_22->setText(QCoreApplication::translate("FCM_Dialog", "Last Modified:", nullptr));
        label_6->setText(QCoreApplication::translate("FCM_Dialog", "Name:", nullptr));
        labelSize_2->setText(QCoreApplication::translate("FCM_Dialog", "Size:", nullptr));
        label_7->setText(QCoreApplication::translate("FCM_Dialog", "Origin:", nullptr));
        lastModified->setText(QCoreApplication::translate("FCM_Dialog", "<flash cookie not selected>", nullptr));
        server->setText(QCoreApplication::translate("FCM_Dialog", "<flash cookie not selected>", nullptr));
        size->setText(QCoreApplication::translate("FCM_Dialog", "<flash cookie not selected>", nullptr));
        label_23->setText(QCoreApplication::translate("FCM_Dialog", "Extracted latin1 strings:", nullptr));
        label_24->setText(QCoreApplication::translate("FCM_Dialog", "These flash cookies are stored on your computer:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = flashCookieTree->headerItem();
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("FCM_Dialog", "Origin", nullptr));
        reloadFromDisk->setText(QCoreApplication::translate("FCM_Dialog", "Reload from disk", nullptr));
        labelPath->setText(QCoreApplication::translate("FCM_Dialog", "Path:", nullptr));
#if QT_CONFIG(tooltip)
        path->setToolTip(QCoreApplication::translate("FCM_Dialog", "Click to open containing folder", nullptr));
#endif // QT_CONFIG(tooltip)
        path->setText(QCoreApplication::translate("FCM_Dialog", "<flash cookie not selected>", nullptr));
        removeAll->setText(QCoreApplication::translate("FCM_Dialog", "Remove all flash cookies", nullptr));
        removeOne->setText(QCoreApplication::translate("FCM_Dialog", "Remove flash cookies", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("FCM_Dialog", "Stored Flash Cookies", nullptr));
        label_16->setText(QCoreApplication::translate("FCM_Dialog", "<html><head/><body><p><span style=\" font-weight:600;\">Flash cookie whitelist</span></p></body></html>", nullptr));
        whiteRemove->setText(QCoreApplication::translate("FCM_Dialog", "Remove", nullptr));
        whiteAdd->setText(QCoreApplication::translate("FCM_Dialog", "Add", nullptr));
        label_17->setText(QCoreApplication::translate("FCM_Dialog", "Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)", nullptr));
        label_21->setText(QCoreApplication::translate("FCM_Dialog", "<html><head/><body><p><span style=\" font-weight:600;\">Flash cookie blacklist</span></p></body></html>", nullptr));
        label_18->setText(QCoreApplication::translate("FCM_Dialog", "Flash cookies from these origins will be deleted without any notification.", nullptr));
        blackRemove->setText(QCoreApplication::translate("FCM_Dialog", "Remove", nullptr));
        blackAdd->setText(QCoreApplication::translate("FCM_Dialog", "Add", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("FCM_Dialog", "Flash Cookies Filtering", nullptr));
        label_13->setText(QCoreApplication::translate("FCM_Dialog", "<html><head/><body><p><span style=\" font-weight:600;\">Flash Cookie Settings</span></p></body></html>", nullptr));
        autoMode->setText(QString());
        labelAutoMode->setText(QCoreApplication::translate("FCM_Dialog", "Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.", nullptr));
        label_19->setText(QCoreApplication::translate("FCM_Dialog", "<html><head/><body><p><span style=\" font-weight:600;\">Note:</span> This settings are just applied to flash cookies, to manage HTTP cookies use <span style=\" font-weight:600;\">Cookies Manager</span>. </p></body></html>", nullptr));
        notification->setText(QString());
        labelNotification->setText(QCoreApplication::translate("FCM_Dialog", "Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.", nullptr));
        deleteAllOnStartExit->setText(QString());
        labelDeleteAll->setText(QCoreApplication::translate("FCM_Dialog", "Delete all flash cookies on exit/start. (except those are in whitelist)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(settingsTab), QCoreApplication::translate("FCM_Dialog", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FCM_Dialog: public Ui_FCM_Dialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FCM_DIALOG_H
