/********************************************************************************
** Form generated from reading UI file 'autofillnotification.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOFILLNOTIFICATION_H
#define UI_AUTOFILLNOTIFICATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "mactoolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_AutoFillNotification
{
public:
    QHBoxLayout *horizontalLayout_2;
    QLabel *icon;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QPushButton *update;
    QPushButton *remember;
    QPushButton *never;
    QPushButton *notnow;
    MacToolButton *closeButton;

    void setupUi(QWidget *AutoFillNotification)
    {
        if (AutoFillNotification->objectName().isEmpty())
            AutoFillNotification->setObjectName("AutoFillNotification");
        AutoFillNotification->resize(897, 40);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AutoFillNotification->sizePolicy().hasHeightForWidth());
        AutoFillNotification->setSizePolicy(sizePolicy);
        horizontalLayout_2 = new QHBoxLayout(AutoFillNotification);
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(5, 4, 5, 4);
        icon = new QLabel(AutoFillNotification);
        icon->setObjectName("icon");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(icon->sizePolicy().hasHeightForWidth());
        icon->setSizePolicy(sizePolicy1);
        icon->setPixmap(QPixmap(QString::fromUtf8(":/icons/other/login.png")));

        horizontalLayout_2->addWidget(icon);

        label = new QLabel(AutoFillNotification);
        label->setObjectName("label");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        update = new QPushButton(AutoFillNotification);
        update->setObjectName("update");

        horizontalLayout->addWidget(update);

        remember = new QPushButton(AutoFillNotification);
        remember->setObjectName("remember");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(remember->sizePolicy().hasHeightForWidth());
        remember->setSizePolicy(sizePolicy3);
        remember->setFocusPolicy(Qt::NoFocus);

        horizontalLayout->addWidget(remember);

        never = new QPushButton(AutoFillNotification);
        never->setObjectName("never");
        sizePolicy3.setHeightForWidth(never->sizePolicy().hasHeightForWidth());
        never->setSizePolicy(sizePolicy3);
        never->setFocusPolicy(Qt::NoFocus);

        horizontalLayout->addWidget(never);

        notnow = new QPushButton(AutoFillNotification);
        notnow->setObjectName("notnow");
        sizePolicy3.setHeightForWidth(notnow->sizePolicy().hasHeightForWidth());
        notnow->setSizePolicy(sizePolicy3);
        notnow->setFocusPolicy(Qt::NoFocus);

        horizontalLayout->addWidget(notnow);


        horizontalLayout_2->addLayout(horizontalLayout);

        closeButton = new MacToolButton(AutoFillNotification);
        closeButton->setObjectName("closeButton");
        closeButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(closeButton);


        retranslateUi(AutoFillNotification);

        QMetaObject::connectSlotsByName(AutoFillNotification);
    } // setupUi

    void retranslateUi(QWidget *AutoFillNotification)
    {
        icon->setText(QString());
        label->setText(QString());
        update->setText(QCoreApplication::translate("AutoFillNotification", "Update", nullptr));
        remember->setText(QCoreApplication::translate("AutoFillNotification", "Remember", nullptr));
        never->setText(QCoreApplication::translate("AutoFillNotification", "Never For This Site", nullptr));
        notnow->setText(QCoreApplication::translate("AutoFillNotification", "Not Now", nullptr));
        closeButton->setText(QString());
        (void)AutoFillNotification;
    } // retranslateUi

};

namespace Ui {
    class AutoFillNotification: public Ui_AutoFillNotification {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOFILLNOTIFICATION_H
