/********************************************************************************
** Form generated from reading UI file 'protocolhandlerdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROTOCOLHANDLERDIALOG_H
#define UI_PROTOCOLHANDLERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ProtocolHandlerDialog
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QTreeWidget *treeWidget;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer;
    QPushButton *remove;

    void setupUi(QDialog *ProtocolHandlerDialog)
    {
        if (ProtocolHandlerDialog->objectName().isEmpty())
            ProtocolHandlerDialog->setObjectName("ProtocolHandlerDialog");
        ProtocolHandlerDialog->resize(483, 332);
        gridLayout = new QGridLayout(ProtocolHandlerDialog);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(ProtocolHandlerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 2);

        treeWidget = new QTreeWidget(ProtocolHandlerDialog);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setIndentation(0);
        treeWidget->setSortingEnabled(true);
        treeWidget->setAllColumnsShowFocus(true);

        gridLayout->addWidget(treeWidget, 0, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        remove = new QPushButton(ProtocolHandlerDialog);
        remove->setObjectName("remove");

        verticalLayout_2->addWidget(remove);


        gridLayout->addLayout(verticalLayout_2, 0, 1, 1, 1);


        retranslateUi(ProtocolHandlerDialog);

        QMetaObject::connectSlotsByName(ProtocolHandlerDialog);
    } // setupUi

    void retranslateUi(QDialog *ProtocolHandlerDialog)
    {
        ProtocolHandlerDialog->setWindowTitle(QCoreApplication::translate("ProtocolHandlerDialog", "Manage protocol handlers", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("ProtocolHandlerDialog", "Site", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("ProtocolHandlerDialog", "Protocol", nullptr));
        remove->setText(QCoreApplication::translate("ProtocolHandlerDialog", "Remove", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProtocolHandlerDialog: public Ui_ProtocolHandlerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROTOCOLHANDLERDIALOG_H
