/********************************************************************************
** Form generated from reading UI file 'docktitlebarwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOCKTITLEBARWIDGET_H
#define UI_DOCKTITLEBARWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "mactoolbutton.h"
#include "toolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_DockTitleBarWidget
{
public:
    QHBoxLayout *horizontalLayout;
    ToolButton *titleButton;
    QSpacerItem *horizontalSpacer;
    MacToolButton *closeButton;

    void setupUi(QWidget *DockTitleBarWidget)
    {
        if (DockTitleBarWidget->objectName().isEmpty())
            DockTitleBarWidget->setObjectName("DockTitleBarWidget");
        DockTitleBarWidget->resize(116, 24);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DockTitleBarWidget->sizePolicy().hasHeightForWidth());
        DockTitleBarWidget->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(DockTitleBarWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 0, 2, 0);
        titleButton = new ToolButton(DockTitleBarWidget);
        titleButton->setObjectName("titleButton");
        titleButton->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        titleButton->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        titleButton->setAutoRaise(true);
        titleButton->setArrowType(Qt::ArrowType::DownArrow);

        horizontalLayout->addWidget(titleButton);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        closeButton = new MacToolButton(DockTitleBarWidget);
        closeButton->setObjectName("closeButton");
        closeButton->setFocusPolicy(Qt::FocusPolicy::NoFocus);
        closeButton->setIconSize(QSize(16, 16));
        closeButton->setAutoRaise(true);

        horizontalLayout->addWidget(closeButton);


        retranslateUi(DockTitleBarWidget);

        QMetaObject::connectSlotsByName(DockTitleBarWidget);
    } // setupUi

    void retranslateUi(QWidget *DockTitleBarWidget)
    {
        closeButton->setText(QString());
        (void)DockTitleBarWidget;
    } // retranslateUi

};

namespace Ui {
    class DockTitleBarWidget: public Ui_DockTitleBarWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DOCKTITLEBARWIDGET_H
