/********************************************************************************
** Form generated from reading UI file 'browsinglibrary.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BROWSINGLIBRARY_H
#define UI_BROWSINGLIBRARY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "fancytabwidget.h"

QT_BEGIN_NAMESPACE

class Ui_BrowsingLibrary
{
public:
    QGridLayout *gridLayout;
    FancyTabWidget *tabs;
    QFrame *frame;
    QFrame *frame_2;
    QHBoxLayout *horizontalLayout;
    QPushButton *importExport;
    QSpacerItem *horizontalSpacer;
    QLineEdit *searchLine;

    void setupUi(QWidget *BrowsingLibrary)
    {
        if (BrowsingLibrary->objectName().isEmpty())
            BrowsingLibrary->setObjectName("BrowsingLibrary");
        BrowsingLibrary->resize(762, 477);
        gridLayout = new QGridLayout(BrowsingLibrary);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tabs = new FancyTabWidget(BrowsingLibrary);
        tabs->setObjectName("tabs");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabs->sizePolicy().hasHeightForWidth());
        tabs->setSizePolicy(sizePolicy);

        gridLayout->addWidget(tabs, 1, 0, 1, 2);

        frame = new QFrame(BrowsingLibrary);
        frame->setObjectName("frame");
        frame->setMinimumSize(QSize(71, 25));

        gridLayout->addWidget(frame, 0, 0, 1, 1);

        frame_2 = new QFrame(BrowsingLibrary);
        frame_2->setObjectName("frame_2");
        horizontalLayout = new QHBoxLayout(frame_2);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, -1, 0);
        importExport = new QPushButton(frame_2);
        importExport->setObjectName("importExport");

        horizontalLayout->addWidget(importExport);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        searchLine = new QLineEdit(frame_2);
        searchLine->setObjectName("searchLine");

        horizontalLayout->addWidget(searchLine);


        gridLayout->addWidget(frame_2, 0, 1, 1, 1);


        retranslateUi(BrowsingLibrary);

        QMetaObject::connectSlotsByName(BrowsingLibrary);
    } // setupUi

    void retranslateUi(QWidget *BrowsingLibrary)
    {
        BrowsingLibrary->setWindowTitle(QCoreApplication::translate("BrowsingLibrary", "Library", nullptr));
        importExport->setText(QCoreApplication::translate("BrowsingLibrary", "Import and Export", nullptr));
        searchLine->setPlaceholderText(QCoreApplication::translate("BrowsingLibrary", "Search...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BrowsingLibrary: public Ui_BrowsingLibrary {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BROWSINGLIBRARY_H
