/********************************************************************************
** Form generated from reading UI file 'certificateinfowidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CERTIFICATEINFOWIDGET_H
#define UI_CERTIFICATEINFOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CertificateInfoWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *label_4;
    QLabel *issuedToCN;
    QLabel *label_8;
    QLabel *issuedToO;
    QLabel *label_10;
    QLabel *issuedToOU;
    QLabel *label_11;
    QLabel *issuedToSN;
    QLabel *label_16;
    QLabel *label_17;
    QLabel *issuedByCN;
    QLabel *label_18;
    QLabel *issuedByO;
    QLabel *label_19;
    QLabel *issuedByOU;
    QLabel *label_20;
    QLabel *label_21;
    QLabel *validityIssuedOn;
    QLabel *label_22;
    QLabel *validityExpiresOn;

    void setupUi(QWidget *CertificateInfoWidget)
    {
        if (CertificateInfoWidget->objectName().isEmpty())
            CertificateInfoWidget->setObjectName("CertificateInfoWidget");
        CertificateInfoWidget->resize(512, 264);
        formLayout = new QFormLayout(CertificateInfoWidget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(CertificateInfoWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, label);

        label_4 = new QLabel(CertificateInfoWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        issuedToCN = new QLabel(CertificateInfoWidget);
        issuedToCN->setObjectName("issuedToCN");
        issuedToCN->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, issuedToCN);

        label_8 = new QLabel(CertificateInfoWidget);
        label_8->setObjectName("label_8");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_8);

        issuedToO = new QLabel(CertificateInfoWidget);
        issuedToO->setObjectName("issuedToO");
        issuedToO->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, issuedToO);

        label_10 = new QLabel(CertificateInfoWidget);
        label_10->setObjectName("label_10");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_10);

        issuedToOU = new QLabel(CertificateInfoWidget);
        issuedToOU->setObjectName("issuedToOU");
        issuedToOU->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, issuedToOU);

        label_11 = new QLabel(CertificateInfoWidget);
        label_11->setObjectName("label_11");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_11);

        issuedToSN = new QLabel(CertificateInfoWidget);
        issuedToSN->setObjectName("issuedToSN");
        issuedToSN->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, issuedToSN);

        label_16 = new QLabel(CertificateInfoWidget);
        label_16->setObjectName("label_16");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_16);

        label_17 = new QLabel(CertificateInfoWidget);
        label_17->setObjectName("label_17");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_17);

        issuedByCN = new QLabel(CertificateInfoWidget);
        issuedByCN->setObjectName("issuedByCN");
        issuedByCN->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, issuedByCN);

        label_18 = new QLabel(CertificateInfoWidget);
        label_18->setObjectName("label_18");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_18);

        issuedByO = new QLabel(CertificateInfoWidget);
        issuedByO->setObjectName("issuedByO");
        issuedByO->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, issuedByO);

        label_19 = new QLabel(CertificateInfoWidget);
        label_19->setObjectName("label_19");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_19);

        issuedByOU = new QLabel(CertificateInfoWidget);
        issuedByOU->setObjectName("issuedByOU");
        issuedByOU->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, issuedByOU);

        label_20 = new QLabel(CertificateInfoWidget);
        label_20->setObjectName("label_20");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_20);

        label_21 = new QLabel(CertificateInfoWidget);
        label_21->setObjectName("label_21");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_21);

        validityIssuedOn = new QLabel(CertificateInfoWidget);
        validityIssuedOn->setObjectName("validityIssuedOn");
        validityIssuedOn->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, validityIssuedOn);

        label_22 = new QLabel(CertificateInfoWidget);
        label_22->setObjectName("label_22");

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label_22);

        validityExpiresOn = new QLabel(CertificateInfoWidget);
        validityExpiresOn->setObjectName("validityExpiresOn");
        validityExpiresOn->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, validityExpiresOn);


        retranslateUi(CertificateInfoWidget);

        QMetaObject::connectSlotsByName(CertificateInfoWidget);
    } // setupUi

    void retranslateUi(QWidget *CertificateInfoWidget)
    {
        label->setText(QCoreApplication::translate("CertificateInfoWidget", "<b>Issued To</b>", nullptr));
        label_4->setText(QCoreApplication::translate("CertificateInfoWidget", "Common Name (CN):", nullptr));
        issuedToCN->setText(QString());
        label_8->setText(QCoreApplication::translate("CertificateInfoWidget", "Organization (O):", nullptr));
        issuedToO->setText(QString());
        label_10->setText(QCoreApplication::translate("CertificateInfoWidget", "Organizational Unit (OU):", nullptr));
        issuedToOU->setText(QString());
        label_11->setText(QCoreApplication::translate("CertificateInfoWidget", "Serial Number:", nullptr));
        issuedToSN->setText(QString());
        label_16->setText(QCoreApplication::translate("CertificateInfoWidget", "<b>Issued By</b>", nullptr));
        label_17->setText(QCoreApplication::translate("CertificateInfoWidget", "Common Name (CN):", nullptr));
        issuedByCN->setText(QString());
        label_18->setText(QCoreApplication::translate("CertificateInfoWidget", "Organization (O):", nullptr));
        issuedByO->setText(QString());
        label_19->setText(QCoreApplication::translate("CertificateInfoWidget", "Organizational Unit (OU):", nullptr));
        issuedByOU->setText(QString());
        label_20->setText(QCoreApplication::translate("CertificateInfoWidget", "<b>Validity</b>", nullptr));
        label_21->setText(QCoreApplication::translate("CertificateInfoWidget", "Issued On:", nullptr));
        validityIssuedOn->setText(QString());
        label_22->setText(QCoreApplication::translate("CertificateInfoWidget", "Expires On:", nullptr));
        validityExpiresOn->setText(QString());
        (void)CertificateInfoWidget;
    } // retranslateUi

};

namespace Ui {
    class CertificateInfoWidget: public Ui_CertificateInfoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CERTIFICATEINFOWIDGET_H
