/****************************************************************************
** Meta object code from reading C++ file 'qmluserscript.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.0/src/lib/plugins/qml/api/userscript/qmluserscript.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmluserscript.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QmlUserScriptE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlUserScript::qt_create_metaobjectdata<qt_meta_tag_ZN13QmlUserScriptE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlUserScript",
        "nameChanged",
        "",
        "name",
        "runsOnSubFramesChanged",
        "runsOnSubFrames",
        "worldIdChanged",
        "worldId",
        "sourceCodeChanged",
        "sourceCode",
        "injectionPointChanged",
        "injectionPoint",
        "null",
        "InjectionPoint",
        "DocumentCreation",
        "DocumentReady",
        "Deferred",
        "ScriptWorldId",
        "MainWorld",
        "ApplicationWorld",
        "UserWorld"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'runsOnSubFramesChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'worldIdChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'sourceCodeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'injectionPointChanged'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'null'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'runsOnSubFrames'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'worldId'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sourceCode'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'injectionPoint'
        QtMocHelpers::PropertyData<enum InjectionPoint>(11, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'InjectionPoint'
        QtMocHelpers::EnumData<enum InjectionPoint>(13, 13, QMC::EnumFlags{}).add({
            {   14, InjectionPoint::DocumentCreation },
            {   15, InjectionPoint::DocumentReady },
            {   16, InjectionPoint::Deferred },
        }),
        // enum 'ScriptWorldId'
        QtMocHelpers::EnumData<enum ScriptWorldId>(17, 17, QMC::EnumFlags{}).add({
            {   18, ScriptWorldId::MainWorld },
            {   19, ScriptWorldId::ApplicationWorld },
            {   20, ScriptWorldId::UserWorld },
        }),
    };
    return QtMocHelpers::metaObjectData<QmlUserScript, qt_meta_tag_ZN13QmlUserScriptE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlUserScript::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QmlUserScriptE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QmlUserScriptE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QmlUserScriptE_t>.metaTypes,
    nullptr
} };

void QmlUserScript::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlUserScript *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->runsOnSubFramesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->worldIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->sourceCodeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->injectionPointChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlUserScript::*)(const QString & )>(_a, &QmlUserScript::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlUserScript::*)(bool )>(_a, &QmlUserScript::runsOnSubFramesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlUserScript::*)(int )>(_a, &QmlUserScript::worldIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlUserScript::*)(const QString & )>(_a, &QmlUserScript::sourceCodeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlUserScript::*)(int )>(_a, &QmlUserScript::injectionPointChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->null(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->runsOnSubFrames(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->worldId(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->sourceCode(); break;
        case 5: *reinterpret_cast<enum InjectionPoint*>(_v) = _t->injectionPoint(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setRunsOnSubFrames(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setWorldId(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setSourceCode(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setInjectionPoint(*reinterpret_cast<enum InjectionPoint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlUserScript::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlUserScript::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QmlUserScriptE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlUserScript::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QmlUserScript::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QmlUserScript::runsOnSubFramesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QmlUserScript::worldIdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QmlUserScript::sourceCodeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QmlUserScript::injectionPointChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
