/****************************************************************************
** Meta object code from reading C++ file 'qmlwheelevent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.0/src/lib/plugins/qml/api/events/qmlwheelevent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlwheelevent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QmlWheelEventE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlWheelEvent::qt_create_metaobjectdata<qt_meta_tag_ZN13QmlWheelEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlWheelEvent",
        "angleDelta",
        "QPoint",
        "buttons",
        "globalPos",
        "globalPosF",
        "QPointF",
        "globalX",
        "globalY",
        "inverted",
        "phase",
        "pixelDelta",
        "pos",
        "posF",
        "source",
        "x",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'angleDelta'
        QtMocHelpers::PropertyData<QPoint>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'buttons'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'globalPos'
        QtMocHelpers::PropertyData<QPoint>(4, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'globalPosF'
        QtMocHelpers::PropertyData<QPointF>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'globalX'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'globalY'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inverted'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'phase'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pixelDelta'
        QtMocHelpers::PropertyData<QPoint>(11, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pos'
        QtMocHelpers::PropertyData<QPoint>(12, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'posF'
        QtMocHelpers::PropertyData<QPointF>(13, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'source'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'x'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'y'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlWheelEvent, qt_meta_tag_ZN13QmlWheelEventE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlWheelEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QmlWheelEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QmlWheelEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QmlWheelEventE_t>.metaTypes,
    nullptr
} };

void QmlWheelEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlWheelEvent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QPoint*>(_v) = _t->angleDelta(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->buttons(); break;
        case 2: *reinterpret_cast<QPoint*>(_v) = _t->globalPos(); break;
        case 3: *reinterpret_cast<QPointF*>(_v) = _t->globalPosF(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->globalX(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->globalY(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->inverted(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->phase(); break;
        case 8: *reinterpret_cast<QPoint*>(_v) = _t->pixelDelta(); break;
        case 9: *reinterpret_cast<QPoint*>(_v) = _t->pos(); break;
        case 10: *reinterpret_cast<QPointF*>(_v) = _t->posF(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->source(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->x(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->y(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlWheelEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlWheelEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QmlWheelEventE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlWheelEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
