/********************************************************************************
** Form generated from reading UI file 'cookiemanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COOKIEMANAGER_H
#define UI_COOKIEMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "squeezelabelv2.h"
#include "treewidget.h"

QT_BEGIN_NAMESPACE

class Ui_CookieManager
{
public:
    QHBoxLayout *horizontalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *search;
    QLabel *label_2;
    TreeWidget *cookieTree;
    QFrame *frame;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_6;
    QLabel *label_7;
    QLabel *label_8;
    SqueezeLabelV2 *name;
    SqueezeLabelV2 *value;
    SqueezeLabelV2 *server;
    QLabel *path;
    SqueezeLabelV2 *secure;
    SqueezeLabelV2 *expiration;
    QFrame *frame_2;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *removeAll;
    QPushButton *removeOne;
    QDialogButtonBox *close;
    QWidget *tab_2;
    QGridLayout *gridLayout_3;
    QLabel *label_9;
    QLabel *label_11;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QPushButton *whiteAdd;
    QPushButton *whiteRemove;
    QListWidget *whiteList;
    QLabel *label_10;
    QLabel *label_12;
    QListWidget *blackList;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QPushButton *blackAdd;
    QPushButton *blackRemove;
    QDialogButtonBox *close2;
    QWidget *tab_3;
    QGridLayout *gridLayout_4;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *filter3rdParty;
    QLabel *label_13;
    QCheckBox *saveCookies;
    QCheckBox *filterTracking;
    QCheckBox *deleteCookiesOnClose;
    QDialogButtonBox *close3;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QDialog *CookieManager)
    {
        if (CookieManager->objectName().isEmpty())
            CookieManager->setObjectName("CookieManager");
        CookieManager->resize(617, 415);
        horizontalLayout = new QHBoxLayout(CookieManager);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(4, 4, 4, 4);
        tabWidget = new QTabWidget(CookieManager);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout = new QGridLayout(tab);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(tab);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        search = new QLineEdit(tab);
        search->setObjectName("search");

        gridLayout->addWidget(search, 0, 1, 1, 1);

        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 2);

        cookieTree = new TreeWidget(tab);
        cookieTree->setObjectName("cookieTree");
        cookieTree->setSelectionMode(QAbstractItemView::ExtendedSelection);
        cookieTree->setSortingEnabled(true);

        gridLayout->addWidget(cookieTree, 2, 0, 1, 2);

        frame = new QFrame(tab);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout_2 = new QGridLayout(frame);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setHorizontalSpacing(6);
        gridLayout_2->setVerticalSpacing(3);
        gridLayout_2->setContentsMargins(-1, 0, 0, 0);
        label_3 = new QLabel(frame);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(frame);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 1, 0, 1, 1);

        label_5 = new QLabel(frame);
        label_5->setObjectName("label_5");

        gridLayout_2->addWidget(label_5, 2, 0, 1, 1);

        label_6 = new QLabel(frame);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 3, 0, 1, 1);

        label_7 = new QLabel(frame);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 4, 0, 1, 1);

        label_8 = new QLabel(frame);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 5, 0, 1, 1);

        name = new SqueezeLabelV2(frame);
        name->setObjectName("name");
        name->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(name, 0, 1, 1, 1);

        value = new SqueezeLabelV2(frame);
        value->setObjectName("value");
        value->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(value, 1, 1, 1, 1);

        server = new SqueezeLabelV2(frame);
        server->setObjectName("server");
        server->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(server, 2, 1, 1, 1);

        path = new QLabel(frame);
        path->setObjectName("path");
        path->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(path, 3, 1, 1, 1);

        secure = new SqueezeLabelV2(frame);
        secure->setObjectName("secure");
        secure->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(secure, 4, 1, 1, 1);

        expiration = new SqueezeLabelV2(frame);
        expiration->setObjectName("expiration");
        expiration->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(expiration, 5, 1, 1, 1);


        gridLayout->addWidget(frame, 3, 0, 1, 2);

        frame_2 = new QFrame(tab);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::NoFrame);
        frame_2->setFrameShadow(QFrame::Raised);
        horizontalLayout_2 = new QHBoxLayout(frame_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        removeAll = new QPushButton(frame_2);
        removeAll->setObjectName("removeAll");

        horizontalLayout_2->addWidget(removeAll);

        removeOne = new QPushButton(frame_2);
        removeOne->setObjectName("removeOne");

        horizontalLayout_2->addWidget(removeOne);

        close = new QDialogButtonBox(frame_2);
        close->setObjectName("close");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(close->sizePolicy().hasHeightForWidth());
        close->setSizePolicy(sizePolicy1);
        close->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_2->addWidget(close);


        gridLayout->addWidget(frame_2, 4, 0, 1, 2);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_3 = new QGridLayout(tab_2);
        gridLayout_3->setObjectName("gridLayout_3");
        label_9 = new QLabel(tab_2);
        label_9->setObjectName("label_9");

        gridLayout_3->addWidget(label_9, 0, 0, 1, 1);

        label_11 = new QLabel(tab_2);
        label_11->setObjectName("label_11");
        label_11->setWordWrap(true);

        gridLayout_3->addWidget(label_11, 1, 0, 1, 2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        whiteAdd = new QPushButton(tab_2);
        whiteAdd->setObjectName("whiteAdd");

        verticalLayout->addWidget(whiteAdd);

        whiteRemove = new QPushButton(tab_2);
        whiteRemove->setObjectName("whiteRemove");

        verticalLayout->addWidget(whiteRemove);


        gridLayout_3->addLayout(verticalLayout, 2, 1, 1, 1);

        whiteList = new QListWidget(tab_2);
        whiteList->setObjectName("whiteList");

        gridLayout_3->addWidget(whiteList, 2, 0, 1, 1);

        label_10 = new QLabel(tab_2);
        label_10->setObjectName("label_10");

        gridLayout_3->addWidget(label_10, 3, 0, 1, 1);

        label_12 = new QLabel(tab_2);
        label_12->setObjectName("label_12");
        label_12->setWordWrap(true);

        gridLayout_3->addWidget(label_12, 4, 0, 1, 2);

        blackList = new QListWidget(tab_2);
        blackList->setObjectName("blackList");

        gridLayout_3->addWidget(blackList, 5, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        blackAdd = new QPushButton(tab_2);
        blackAdd->setObjectName("blackAdd");

        verticalLayout_2->addWidget(blackAdd);

        blackRemove = new QPushButton(tab_2);
        blackRemove->setObjectName("blackRemove");

        verticalLayout_2->addWidget(blackRemove);


        gridLayout_3->addLayout(verticalLayout_2, 5, 1, 1, 1);

        close2 = new QDialogButtonBox(tab_2);
        close2->setObjectName("close2");
        close2->setStandardButtons(QDialogButtonBox::Close);

        gridLayout_3->addWidget(close2, 6, 0, 1, 2);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_4 = new QGridLayout(tab_3);
        gridLayout_4->setObjectName("gridLayout_4");
        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 1, 0, 1, 1);

        filter3rdParty = new QCheckBox(tab_3);
        filter3rdParty->setObjectName("filter3rdParty");

        gridLayout_4->addWidget(filter3rdParty, 4, 1, 1, 1);

        label_13 = new QLabel(tab_3);
        label_13->setObjectName("label_13");

        gridLayout_4->addWidget(label_13, 0, 0, 1, 3);

        saveCookies = new QCheckBox(tab_3);
        saveCookies->setObjectName("saveCookies");

        gridLayout_4->addWidget(saveCookies, 1, 1, 1, 2);

        filterTracking = new QCheckBox(tab_3);
        filterTracking->setObjectName("filterTracking");

        gridLayout_4->addWidget(filterTracking, 3, 1, 1, 2);

        deleteCookiesOnClose = new QCheckBox(tab_3);
        deleteCookiesOnClose->setObjectName("deleteCookiesOnClose");

        gridLayout_4->addWidget(deleteCookiesOnClose, 5, 1, 1, 2);

        close3 = new QDialogButtonBox(tab_3);
        close3->setObjectName("close3");
        close3->setStandardButtons(QDialogButtonBox::Close);

        gridLayout_4->addWidget(close3, 8, 3, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_3, 6, 3, 1, 1);

        tabWidget->addTab(tab_3, QString());

        horizontalLayout->addWidget(tabWidget);


        retranslateUi(CookieManager);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CookieManager);
    } // setupUi

    void retranslateUi(QDialog *CookieManager)
    {
        CookieManager->setWindowTitle(QCoreApplication::translate("CookieManager", "Cookies", nullptr));
        label->setText(QCoreApplication::translate("CookieManager", "Find: ", nullptr));
        label_2->setText(QCoreApplication::translate("CookieManager", "These cookies are stored on your computer:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = cookieTree->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("CookieManager", "Cookie name", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("CookieManager", "Server", nullptr));
        label_3->setText(QCoreApplication::translate("CookieManager", "Name:", nullptr));
        label_4->setText(QCoreApplication::translate("CookieManager", "Value:", nullptr));
        label_5->setText(QCoreApplication::translate("CookieManager", "Server:", nullptr));
        label_6->setText(QCoreApplication::translate("CookieManager", "Path:", nullptr));
        label_7->setText(QCoreApplication::translate("CookieManager", "Secure:", nullptr));
        label_8->setText(QCoreApplication::translate("CookieManager", "Expiration:", nullptr));
        name->setText(QCoreApplication::translate("CookieManager", "<cookie not selected>", nullptr));
        value->setText(QCoreApplication::translate("CookieManager", "<cookie not selected>", nullptr));
        server->setText(QCoreApplication::translate("CookieManager", "<cookie not selected>", nullptr));
        path->setText(QCoreApplication::translate("CookieManager", "<cookie not selected>", nullptr));
        secure->setText(QCoreApplication::translate("CookieManager", "<cookie not selected>", nullptr));
        expiration->setText(QCoreApplication::translate("CookieManager", "<cookie not selected>", nullptr));
        removeAll->setText(QCoreApplication::translate("CookieManager", "Remove all cookies", nullptr));
        removeOne->setText(QCoreApplication::translate("CookieManager", "Remove cookies", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("CookieManager", "Stored Cookies", nullptr));
        label_9->setText(QCoreApplication::translate("CookieManager", "<b>Cookie whitelist</b>", nullptr));
        label_11->setText(QCoreApplication::translate("CookieManager", "Cookies from these servers will ALWAYS be accepted (even if you have disabled saving cookies)", nullptr));
        whiteAdd->setText(QCoreApplication::translate("CookieManager", "Add", nullptr));
        whiteRemove->setText(QCoreApplication::translate("CookieManager", "Remove", nullptr));
        label_10->setText(QCoreApplication::translate("CookieManager", "<b>Cookie blacklist</b>", nullptr));
        label_12->setText(QCoreApplication::translate("CookieManager", "Cookies from these servers will NEVER be accepted", nullptr));
        blackAdd->setText(QCoreApplication::translate("CookieManager", "Add", nullptr));
        blackRemove->setText(QCoreApplication::translate("CookieManager", "Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("CookieManager", "Cookie Filtering", nullptr));
        filter3rdParty->setText(QCoreApplication::translate("CookieManager", "Filter 3rd party cookies", nullptr));
        label_13->setText(QCoreApplication::translate("CookieManager", "<b>Cookie Settings</b>", nullptr));
        saveCookies->setText(QCoreApplication::translate("CookieManager", "Allow storing of cookies", nullptr));
        filterTracking->setText(QCoreApplication::translate("CookieManager", "Filter tracking cookies", nullptr));
        deleteCookiesOnClose->setText(QCoreApplication::translate("CookieManager", "Delete cookies on close", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("CookieManager", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CookieManager: public Ui_CookieManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COOKIEMANAGER_H
