/********************************************************************************
** Form generated from reading UI file 'addacceptlanguage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDACCEPTLANGUAGE_H
#define UI_ADDACCEPTLANGUAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AddAcceptLanguage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QListWidget *listWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QLineEdit *ownDefinition;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AddAcceptLanguage)
    {
        if (AddAcceptLanguage->objectName().isEmpty())
            AddAcceptLanguage->setObjectName("AddAcceptLanguage");
        AddAcceptLanguage->resize(366, 283);
        verticalLayout = new QVBoxLayout(AddAcceptLanguage);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(AddAcceptLanguage);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        listWidget = new QListWidget(AddAcceptLanguage);
        listWidget->setObjectName("listWidget");

        verticalLayout->addWidget(listWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(AddAcceptLanguage);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        ownDefinition = new QLineEdit(AddAcceptLanguage);
        ownDefinition->setObjectName("ownDefinition");

        horizontalLayout->addWidget(ownDefinition);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(AddAcceptLanguage);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AddAcceptLanguage);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AddAcceptLanguage, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AddAcceptLanguage, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AddAcceptLanguage);
    } // setupUi

    void retranslateUi(QDialog *AddAcceptLanguage)
    {
        AddAcceptLanguage->setWindowTitle(QCoreApplication::translate("AddAcceptLanguage", "Add Language", nullptr));
        label->setText(QCoreApplication::translate("AddAcceptLanguage", "Choose preferred language for web sites", nullptr));
        label_2->setText(QCoreApplication::translate("AddAcceptLanguage", "Personal definition:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddAcceptLanguage: public Ui_AddAcceptLanguage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDACCEPTLANGUAGE_H
