/* ============================================================
* Falkon - Qt web browser
* Copyright (C) 2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#include "bookmarksitemdelegate.h"
#include "bookmarkstreeview.h"
#include "bookmarksmodel.h"
#include "bookmarkitem.h"

#include <QStyleOption>
#include <QApplication>
#include <QStyle>

BookmarksItemDelegate::BookmarksItemDelegate(QTreeView* parent)
    : QStyledItemDelegate(parent)
    , m_tree(parent)
{
    Q_ASSERT(m_tree);
}

void BookmarksItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
{
    QStyledItemDelegate::paint(painter, option, index);

    if (index.data(BookmarksModel::TypeRole).toInt() == BookmarkItem::Separator) {
        QStyleOption opt = option;
        opt.state &= ~QStyle::State_Horizontal;

        // We need to fake continuous line over 2 columns
        if (m_tree->model()->columnCount(index) == 2) {
            if (index.column() == 1) {
                opt.rect = m_lastRect;
            }
            else {
                opt.rect.setWidth(opt.rect.width() + m_tree->columnWidth(1));
                m_lastRect = opt.rect;
            }
        }

        QApplication::style()->drawPrimitive(QStyle::PE_IndicatorToolBarSeparator, &opt, painter);
    }
}
