/****************************************************************************
** Meta object code from reading C++ file 'qmltabs.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.0/src/lib/plugins/qml/api/tabs/qmltabs.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmltabs.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7QmlTabsE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlTabs::qt_create_metaobjectdata<qt_meta_tag_ZN7QmlTabsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlTabs",
        "changed",
        "",
        "windowId",
        "tabInserted",
        "QVariantMap",
        "map",
        "tabRemoved",
        "tabMoved",
        "setCurrentIndex",
        "nextTab",
        "previousTab",
        "moveTab",
        "pinTab",
        "unpinTab",
        "detachTab",
        "duplicate",
        "closeTab",
        "reloadTab",
        "stopTab",
        "get",
        "QmlTab*",
        "normalTabsCount",
        "pinnedTabsCount",
        "getAll",
        "QList<QObject*>",
        "search",
        "addTab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabInserted'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'tabRemoved'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'tabMoved'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'setCurrentIndex'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(9, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'nextTab'
        QtMocHelpers::MethodData<bool(int)>(10, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'nextTab'
        QtMocHelpers::MethodData<bool()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'previousTab'
        QtMocHelpers::MethodData<bool(int)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'previousTab'
        QtMocHelpers::MethodData<bool()>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'moveTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'pinTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(13, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'unpinTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'detachTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'duplicate'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'closeTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'reloadTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'stopTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QmlTab *(const QVariantMap &) const>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'normalTabsCount'
        QtMocHelpers::MethodData<int(int) const>(22, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'normalTabsCount'
        QtMocHelpers::MethodData<int() const>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'pinnedTabsCount'
        QtMocHelpers::MethodData<int(int) const>(23, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'pinnedTabsCount'
        QtMocHelpers::MethodData<int() const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'getAll'
        QtMocHelpers::MethodData<QList<QObject*>(const QVariantMap &) const>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'getAll'
        QtMocHelpers::MethodData<QList<QObject*>() const>(24, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 25),
        // Method 'search'
        QtMocHelpers::MethodData<QList<QObject*>(const QVariantMap &)>(26, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'addTab'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlTabs, qt_meta_tag_ZN7QmlTabsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlTabs::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7QmlTabsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7QmlTabsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7QmlTabsE_t>.metaTypes,
    nullptr
} };

void QmlTabs::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlTabs *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->tabInserted((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->tabRemoved((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->tabMoved((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: { bool _r = _t->setCurrentIndex((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->nextTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->nextTab();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->previousTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->previousTab();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->moveTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->pinTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->unpinTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->detachTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->duplicate((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->closeTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->reloadTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->stopTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QmlTab* _r = _t->get((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QmlTab**>(_a[0]) = std::move(_r); }  break;
        case 18: { int _r = _t->normalTabsCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: { int _r = _t->normalTabsCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { int _r = _t->pinnedTabsCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->pinnedTabsCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: { QList<QObject*> _r = _t->getAll((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QList<QObject*> _r = _t->getAll();
            if (_a[0]) *reinterpret_cast<QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QList<QObject*> _r = _t->search((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->addTab((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlTabs::*)(int )>(_a, &QmlTabs::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTabs::*)(const QVariantMap & )>(_a, &QmlTabs::tabInserted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTabs::*)(const QVariantMap & )>(_a, &QmlTabs::tabRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlTabs::*)(const QVariantMap & )>(_a, &QmlTabs::tabMoved, 3))
            return;
    }
}

const QMetaObject *QmlTabs::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlTabs::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7QmlTabsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlTabs::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void QmlTabs::changed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QmlTabs::tabInserted(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QmlTabs::tabRemoved(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QmlTabs::tabMoved(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
