/********************************************************************************
** Form generated from reading UI file 'pluginslist.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLUGINSLIST_H
#define UI_PLUGINSLIST_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PluginsList
{
public:
    QVBoxLayout *verticalLayout;
    QLineEdit *search;
    QListWidget *list;
    QHBoxLayout *horizontalLayout;
    QPushButton *butSettings;
    QPushButton *butRemove;
    QSpacerItem *horizontalSpacer;
    QLabel *label;

    void setupUi(QWidget *PluginsList)
    {
        if (PluginsList->objectName().isEmpty())
            PluginsList->setObjectName("PluginsList");
        PluginsList->resize(623, 462);
        verticalLayout = new QVBoxLayout(PluginsList);
        verticalLayout->setObjectName("verticalLayout");
        search = new QLineEdit(PluginsList);
        search->setObjectName("search");

        verticalLayout->addWidget(search);

        list = new QListWidget(PluginsList);
        list->setObjectName("list");
        list->setAlternatingRowColors(true);
        list->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
        list->setUniformItemSizes(true);
        list->setWordWrap(true);

        verticalLayout->addWidget(list);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        butSettings = new QPushButton(PluginsList);
        butSettings->setObjectName("butSettings");
        butSettings->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(butSettings->sizePolicy().hasHeightForWidth());
        butSettings->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(butSettings);

        butRemove = new QPushButton(PluginsList);
        butRemove->setObjectName("butRemove");
        butRemove->setEnabled(false);

        horizontalLayout->addWidget(butRemove);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label = new QLabel(PluginsList);
        label->setObjectName("label");
        label->setOpenExternalLinks(true);

        horizontalLayout->addWidget(label);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(PluginsList);

        QMetaObject::connectSlotsByName(PluginsList);
    } // setupUi

    void retranslateUi(QWidget *PluginsList)
    {
        search->setPlaceholderText(QCoreApplication::translate("PluginsList", "Enter name", nullptr));
        butSettings->setText(QCoreApplication::translate("PluginsList", "Settings", nullptr));
        butRemove->setText(QCoreApplication::translate("PluginsList", "Remove", nullptr));
        label->setText(QCoreApplication::translate("PluginsList", "<a href=\"https://store.kde.org/browse/cat/571/\">Get more extensions...</a>", nullptr));
        (void)PluginsList;
    } // retranslateUi

};

namespace Ui {
    class PluginsList: public Ui_PluginsList {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLUGINSLIST_H
